@@ -3,7 +3,7 @@
  * @brief Implementation of the ArpScreen class
  *
  *
- *      Copyright 2009 - 2016 <qmidiarp-devel@lists.sourceforge.net>
+ *      Copyright 2009 - 2017 <qmidiarp-devel@lists.sourceforge.net>
  *
  *      This program is free software; you can redistribute it and/or modify
  *      it under the terms of the GNU General Public License as published by
@@ -22,21 +22,13 @@
  *
  */
 
-#include <QPainter>
-#include <QPaintDevice>
-#include <QPen>
-#include <QPixmap>
-
 #include "arpscreen.h"
 
 
-ArpScreen::ArpScreen(QWidget* parent) : QWidget (parent)
+ArpScreen::ArpScreen(QWidget* parent) : Screen (parent)
 {
     setPalette(QPalette(QColor(0, 20, 100), QColor(0, 20, 100)));
     pattern=" ";
-    grooveTick = 0;
-    grooveVelocity = 0;
-    grooveLength = 0;
 
     // These parameters are transferred by ArpWidget upon each pattern change
     maxOctave = 0;
@@ -44,12 +36,6 @@ ArpScreen::ArpScreen(QWidget* parent) : QWidget (parent)
     nSteps = 1.0;
     minStepWidth = 1.0;
     patternMaxIndex = 0;
-    isMuted = false;
-    needsRedraw = false;
-}
-
-ArpScreen::~ArpScreen()
-{
 }
 
 // Paint event handler.
@@ -61,38 +47,10 @@ void ArpScreen::paintEvent(QPaintEvent*)
     p.setFont(QFont("Helvetica", 8));
     p.setPen(pen);
 
-    int l1, l2;
-    int beat = 4;
-    double stepwd = 1.0;
-    double curstep = 0.0;
-    int nlines = 0;
-    int notelen;
-    int dx = 0;
-    int ypos, xpos;
-    int octYoffset;
     int w = QWidget::width();
     int h = QWidget::height();
     int notestreak_thick = 2;
 
-    double len;
-    int xscale, yscale, ofs;
-    int x, x1;
-    int patternLen = pattern.length();
-    bool chordmd = false;
-    int octave = 0;
-    int semitone = 0;
-    double vel =1.0;
-    double v = 0;
-    int grv_cur_sft = 0;
-    int grv_cur_len = 0;
-    int grv_cur_vel = 0;
-    int grooveIndex = 0;
-    int chordindex = 0;
-    int polyindex = 0;
-    l2 = 0;
-    QChar c;
-
-
     //Green Filled Frame
     if (isMuted)
         p.fillRect(0, 0, w, h, QColor(70, 70, 70));
@@ -104,24 +62,24 @@ void ArpScreen::paintEvent(QPaintEvent*)
     p.setPen(QColor(20, 160, 20));
 
     //Grid
-    len = nSteps;
-    xscale = (w - 2 * ARPSCR_HMARG) / len;
-    yscale = h - 2 * ARPSCR_VMARG;
-
-    //Beat separators
-    for (l1 = 0; l1 < nSteps + 1; l1++) {
+    double len = nSteps;
+    int xscale = (w - 2 * ARPSCR_HMARG) / len;
+    int yscale = h - 2 * ARPSCR_VMARG;
 
+    //Beat separators (4 beats)
+    for (int l1 = 0; l1 < nSteps + 1; l1++) {
+        int ofs;
         if (l1 < 10) {
             ofs = w / len * .5 - 4 + ARPSCR_HMARG;
         } else {
             ofs = w / len * .5 - 6 + ARPSCR_HMARG;
         }
-        if ((bool)(l1%beat)) {
+        if ((bool)(l1%4)) {
             p.setPen(QColor(60, 180, 60));
         } else {
             p.setPen(QColor(60, 180, 150));
         }
-        x = l1 * xscale;
+        int x = l1 * xscale;
         p.drawLine(ARPSCR_HMARG + x, ARPSCR_VMARG,
                 ARPSCR_HMARG + x, h-ARPSCR_VMARG);
 
@@ -133,8 +91,8 @@ void ArpScreen::paintEvent(QPaintEvent*)
             // Beat divisor separators
             p.setPen(QColor(40, 100, 40));
 
-            for (l2 = 1; l2 < 1.0/minStepWidth; l2++) {
-                x1 = x + l2 * xscale * minStepWidth;
+            for (int l2 = 1; l2 < 1.0/minStepWidth; l2++) {
+                int x1 = x + l2 * xscale * minStepWidth;
                 if (x1 < xscale*len)
                     p.drawLine(ARPSCR_HMARG + x1,
                             ARPSCR_VMARG, ARPSCR_HMARG + x1,
@@ -146,8 +104,8 @@ void ArpScreen::paintEvent(QPaintEvent*)
     //Octave separators and numbers
     p.setPen(QColor(40, 120, 40));
     int noctaves = maxOctave - minOctave + 1;
-    for (l1 = 0; l1 < noctaves + 1; l1++) {
-        ypos = yscale * l1 / noctaves + ARPSCR_VMARG;
+    for (int l1 = 0; l1 < noctaves + 1; l1++) {
+        int ypos = yscale * l1 / noctaves + ARPSCR_VMARG;
         p.drawLine(ARPSCR_HMARG, ypos, w - ARPSCR_HMARG, ypos);
         p.drawText(ARPSCR_HMARG / 2 - 3,
                 yscale * (l1 + 0.5) / noctaves + ARPSCR_VMARG + 4,
@@ -155,29 +113,36 @@ void ArpScreen::paintEvent(QPaintEvent*)
     }
 
     //Draw arpTicks
-    curstep= 0.0;
-    notelen = xscale/8;
-    stepwd = 1.0;
-    vel = 0.8;
-    octave = 0;
-    semitone = 0;
-    chordmd = false;
-    chordindex = 0;
+    double curstep= 0.0;
+    int notelen = xscale/8;
+    double stepwd = 1.0;
+    double vel = 0.8;
+    int octave = 0;
+    int semitone = 0;
+    bool chordmd = false;
+    int chordindex = 0;
 
-
-    for (l1 = 0; l1 < patternLen; l1++)
+    int grooveIndex = 0;
+    int polyindex = 0;
+    int nlines = 0;
+    
+    for (int l1 = 0; l1 < pattern.length(); l1++)
     {
-        c = pattern.at(l1);
+        int forward = 0;
+        QChar c = pattern.at(l1);
         if (c.isDigit())
         {
             nlines = c.digitValue() + 1;
-            if (chordmd && (nlines == 1) && chordindex) polyindex++;
+            if (chordmd && (nlines == 1) && chordindex) {
+                polyindex++;
+            }
             if (!chordindex)
             {
                 if (chordmd) chordindex++;
                 curstep += stepwd;
-                grooveIndex++;
             }
+            if (!chordmd) forward = 1;
+
         }
         else
         {
@@ -189,8 +154,10 @@ void ArpScreen::paintEvent(QPaintEvent*)
                     break;
 
                 case ')':
+                    if (chordmd) forward = 1;
                     chordmd = false;
                     chordindex = 0;
+                    nlines = 0;
                     break;
 
                 case '>':
@@ -206,9 +173,10 @@ void ArpScreen::paintEvent(QPaintEvent*)
                     break;
 
                 case 'p':
-                    if (!chordmd)
+                    if (!chordmd) {
                         curstep += stepwd;
-                        grooveIndex++;
+                        forward = 1;
+                    }
                    break;
 
                 case '+':
@@ -253,43 +221,45 @@ void ArpScreen::paintEvent(QPaintEvent*)
             }
         }
 
-        grv_cur_sft = ((grooveIndex % 2)) ? 0 : grooveTick ;
-        grv_cur_len = ((grooveIndex % 2)) ? grooveLength : -grooveLength ;
-        grv_cur_vel = ((grooveIndex % 2)) ? grooveVelocity : -grooveVelocity ;
+        int grv_cur_sft = ((grooveIndex % 2)) ? grooveTick : 0 ;
+        int grv_cur_len = ((grooveIndex % 2)) ? -grooveLength : grooveLength ;
+        int grv_cur_vel = ((grooveIndex % 2)) ? -grooveVelocity : grooveVelocity ;
 
-        if (c.isDigit()) {
-            octYoffset = (octave - minOctave) * (patternMaxIndex + 1);
-            x = (curstep - stepwd + 0.01 * (double)grv_cur_sft * stepwd) * xscale;
-            dx = notelen * (1.0 + 0.005 * (double)grv_cur_len);
-            v = vel * (1.0 + 0.005 * (double)grv_cur_vel) - .8;
+        if (c.isDigit() || c == 'p') {
+            int octYoffset = (octave - minOctave) * (patternMaxIndex + 1);
+            int x = (curstep - stepwd + 0.01 * (double)grv_cur_sft * stepwd) * xscale;
+            int dx = notelen * (1.0 + 0.005 * (double)grv_cur_len);
+            double v = vel * (1.0 + 0.005 * (double)grv_cur_vel) - .8;
+            pen.setWidth(notestreak_thick);
+            int xpos = ARPSCR_HMARG + x + pen.width() / 2;
 
+            // Arp ticks
             if (nlines > 0) {
-                pen.setWidth(notestreak_thick);
+                int ypos = yscale - yscale * (nlines - 1 + octYoffset)
+                        / (patternMaxIndex + 1) / noctaves
+                        + ARPSCR_VMARG - 3 + notestreak_thick
+                        - notestreak_thick * polyindex;
                 if (semitone != 0)
                     pen.setColor(QColor(50 + 60 * v, 130 + 40 * v, abs(100 + 10 * semitone) % 256));
                 else
                     pen.setColor(QColor(80 + 60 * v, 160 + 40 * v, 80 + 60 * v));
                 p.setPen(pen);
-                ypos = yscale - yscale * (nlines - 1 + octYoffset)
-                            / (patternMaxIndex + 1) / noctaves
-                            + ARPSCR_VMARG - 3 + notestreak_thick
-                            - notestreak_thick * polyindex;
-                xpos = ARPSCR_HMARG + x + pen.width() / 2;
                 p.drawLine(xpos, ypos, xpos + dx - pen.width(), ypos);
-                // Cursor
-                if (grooveIndex == currentIndex) {
-                    pen.setWidth(notestreak_thick * 2);
-                    p.setPen(pen);
-                    ypos = h - 2;
-                    p.drawLine(xpos, ypos, xpos + dx - pen.width(), ypos);
-                }
-                pen.setWidth(1);
             }
+            // Cursor
+            if (grooveIndex == currentIndex) {
+                int ypos = h - 2;
+                pen.setWidth(notestreak_thick * 2);
+                p.setPen(pen);
+                p.drawLine(xpos, ypos, xpos + dx - pen.width(), ypos);
+            }
+            pen.setWidth(1);
         }
+        grooveIndex+=forward;
     }
 }
 
-void ArpScreen::updateScreen(const QString& p_pattern, int p_minOctave,
+void ArpScreen::updateData(const QString& p_pattern, int p_minOctave,
                                 int p_maxOctave, double p_minStepWidth,
                                 double p_nSteps, int p_patternMaxIndex)
 {
@@ -302,41 +272,8 @@ void ArpScreen::updateScreen(const QString& p_pattern, int p_minOctave,
     needsRedraw = true;
 }
 
-void ArpScreen::updateScreen(int p_index)
+void ArpScreen::updateCursor(int p_index)
 {
     currentIndex = p_index;
     needsRedraw = true;
 }
-
-void ArpScreen::updateDraw()
-{
-    if (!needsRedraw) return;
-    needsRedraw = false;
-    update();
-}
-
-void ArpScreen::newGrooveValues(int tick, int vel, int length)
-{
-    grooveTick = tick;
-    grooveVelocity = vel;
-    grooveLength = length;
-    needsRedraw = true;
-}
-
-void ArpScreen::setMuted(bool on)
-{
-    isMuted = on;
-    needsRedraw = true;
-}
-
-QSize ArpScreen::sizeHint() const
-{
-    return QSize(ARPSCR_MIN_W, ARPSCR_MIN_H);
-}
-
-QSizePolicy ArpScreen::sizePolicy() const
-{
-    return QSizePolicy(QSizePolicy::MinimumExpanding,
-            QSizePolicy::MinimumExpanding);
-}
-
