@@ -3,7 +3,7 @@
  * @brief Implements the ArpWidget GUI class.
  *
  *
- *      Copyright 2009 - 2016 <qmidiarp-devel@lists.sourceforge.net>
+ *      Copyright 2009 - 2017 <qmidiarp-devel@lists.sourceforge.net>
  *
  *      This program is free software; you can redistribute it and/or modify
  *      it under the terms of the GNU General Public License as published by
@@ -21,12 +21,10 @@
  *      MA 02110-1301, USA.
  */
 
-#include <QBoxLayout>
 #include <QFile>
 #include <QTextStream>
 #include <QInputDialog>
 #include <QDir>
-#include <QMessageBox>
 
 #include "midiarp.h"
 #include "arpwidget.h"
@@ -44,18 +42,18 @@
 
 
 #ifdef APPBUILD
-ArpWidget::ArpWidget(MidiArp *p_midiWorker, GlobStore *p_globStore,
+ArpWidget::ArpWidget(MidiArp *p_midiArp, GlobStore *p_globStore,
     int portCount, bool compactStyle,
     bool mutedAdd, bool inOutVisible, const QString& p_name):
-    InOutBox(p_midiWorker, p_globStore, portCount, compactStyle, inOutVisible, p_name),
-    midiWorker(p_midiWorker)
+    InOutBox(p_midiArp, p_globStore, portCount, compactStyle, inOutVisible, p_name),
+    midiArp(p_midiArp)
 {
 #else
 ArpWidget::ArpWidget(
     bool compactStyle,
     bool mutedAdd, bool inOutVisible):
     InOutBox(compactStyle, inOutVisible, "Arp:"),
-    midiWorker(NULL)
+    midiArp(NULL)
 {
 #endif
 
@@ -104,7 +102,7 @@ ArpWidget::ArpWidget(
 
     repeatPatternThroughChord = new QComboBox;
     QStringList repeatPatternNames;
-    repeatPatternNames << tr("Static") << tr("Up") << tr("Down") << tr("Random");
+    repeatPatternNames << tr("Static") << tr("Up") << tr("Down") << tr("Random") << tr("As Played");
     repeatPatternThroughChord->insertItems(0, repeatPatternNames);
     repeatPatternThroughChord->setToolTip(tr("Repeat mode - This is how notes are sequenced\n"
                             "when a chord is pressed"));
@@ -288,7 +286,7 @@ ArpWidget::ArpWidget(
 #ifdef APPBUILD
 MidiArp *ArpWidget::getMidiWorker()
 {
-    return (midiWorker);
+    return (midiArp);
 }
 
 void ArpWidget::writeData(QXmlStreamWriter& xml)
@@ -296,26 +294,26 @@ void ArpWidget::writeData(QXmlStreamWriter& xml)
         writeCommonData(xml);
 
         xml.writeStartElement("pattern");
-            xml.writeTextElement("pattern", midiWorker->pattern);
+            xml.writeTextElement("pattern", QString::fromStdString(midiArp->pattern));
             xml.writeTextElement("repeatMode", QString::number(
-                midiWorker->repeatPatternThroughChord));
+                midiArp->repeatPatternThroughChord));
             xml.writeTextElement("octaveMode", QString::number(
-                midiWorker->octMode));
+                midiArp->octMode));
             xml.writeTextElement("octaveLow", QString::number(
-                midiWorker->octLow));
+                midiArp->octLow));
             xml.writeTextElement("octaveHigh", QString::number(
-                midiWorker->octHigh));
+                midiArp->octHigh));
             xml.writeTextElement("latchMode", QString::number(
                 latchModeAction->isChecked()));
         xml.writeEndElement();
 
         xml.writeStartElement("random");
             xml.writeTextElement("tick", QString::number(
-                midiWorker->randomTickAmp));
+                midiArp->randomTickAmp));
             xml.writeTextElement("velocity", QString::number(
-                midiWorker->randomVelocityAmp));
+                midiArp->randomVelocityAmp));
             xml.writeTextElement("length", QString::number(
-                midiWorker->randomLengthAmp));
+                midiArp->randomLengthAmp));
         xml.writeEndElement();
 
         xml.writeStartElement("envelope");
@@ -391,7 +389,7 @@ void ArpWidget::readData(QXmlStreamReader& xml)
     updateChIn(chIn->currentIndex());
     updateChannelOut(channelOut->currentIndex());
     updatePortOut(portOut->currentIndex());
-
+    midiArp->needsGUIUpdate = false;
     modified = false;
 }
 #endif
@@ -400,13 +398,13 @@ void ArpWidget::readData(QXmlStreamReader& xml)
 void ArpWidget::updateText(const QString& newtext)
 {
     patternPresetBox->setCurrentIndex(0);
-    if (!midiWorker) return;
+    if (!midiArp) return;
     textRemoveAction->setEnabled(false);
     textStoreAction->setEnabled(true);
-    midiWorker->updatePattern(newtext);
-    screen->updateScreen(newtext, midiWorker->minOctave,
-                    midiWorker->maxOctave, midiWorker->minStepWidth,
-                    midiWorker->nSteps, midiWorker->patternMaxIndex);
+    midiArp->updatePattern(newtext.toStdString());
+    screen->updateData(newtext, midiArp->minOctave,
+                    midiArp->maxOctave, midiArp->minStepWidth,
+                    midiArp->nSteps, midiArp->patternMaxIndex);
 
     modified = true;
 }
@@ -415,14 +413,15 @@ void ArpWidget::selectPatternPreset(int val)
 {
     if (val < patternPresets.count()) {
         if (val) {
+            patternText->setText("");
             patternText->setText(patternPresets.at(val));
-            if (!midiWorker) return;
+            if (!midiArp) return;
             patternPresetBox->setCurrentIndex(val);
             textStoreAction->setEnabled(false);
             textRemoveAction->setEnabled(true);
         }
         else {
-            if (!midiWorker) return;
+            if (!midiArp) return;
             textRemoveAction->setEnabled(false);
         }
         modified = true;
@@ -464,45 +463,45 @@ void ArpWidget::loadPatternPresets()
 
 void ArpWidget::updateRepeatPattern(int val)
 {
-    if (midiWorker) midiWorker->repeatPatternThroughChord = val;
+    if (midiArp) midiArp->repeatPatternThroughChord = val;
     modified = true;
 }
 
 void ArpWidget::updateOctaveMode(int val)
 {
-    if (midiWorker) midiWorker->updateOctaveMode(val);
+    if (midiArp) midiArp->updateOctaveMode(val);
     modified = true;
 }
 
 void ArpWidget::updateOctaveLow(int val)
 {
-    if (midiWorker) midiWorker->octLow = -val;
+    if (midiArp) midiArp->octLow = -val;
     modified = true;
 }
 
 void ArpWidget::updateOctaveHigh(int val)
 {
-    if (midiWorker) midiWorker->octHigh = val;
+    if (midiArp) midiArp->octHigh = val;
     modified = true;
 }
 
 void ArpWidget::updateRandomLengthAmp(int val)
 {
-    if (midiWorker) midiWorker->updateRandomLengthAmp(val);
+    if (midiArp) midiArp->updateRandomLengthAmp(val);
     checkIfRandomSet();
     modified = true;
 }
 
 void ArpWidget::updateRandomTickAmp(int val)
 {
-    if (midiWorker) midiWorker->updateRandomTickAmp(val);
+    if (midiArp) midiArp->updateRandomTickAmp(val);
     checkIfRandomSet();
     modified = true;
 }
 
 void ArpWidget::updateRandomVelocityAmp(int val)
 {
-    if (midiWorker) midiWorker->updateRandomVelocityAmp(val);
+    if (midiArp) midiArp->updateRandomVelocityAmp(val);
     checkIfRandomSet();
     modified = true;
 }
@@ -522,14 +521,14 @@ void ArpWidget::checkIfRandomSet()
 
 void ArpWidget::updateAttackTime(int val)
 {
-    if (midiWorker) midiWorker->updateAttackTime(val);
+    if (midiArp) midiArp->updateAttackTime(val);
     checkIfEnvelopeSet();
     modified = true;
 }
 
 void ArpWidget::updateReleaseTime(int val)
 {
-    if (midiWorker) midiWorker->updateReleaseTime(val);
+    if (midiArp) midiArp->updateReleaseTime(val);
     checkIfEnvelopeSet();
     modified = true;
 }
@@ -620,7 +619,7 @@ void ArpWidget::setEnvelopeVisible(bool on)
 
 void ArpWidget::setLatchMode(bool on)
 {
-    if (midiWorker) midiWorker->setLatchMode(on);
+    if (midiArp) midiArp->setLatchMode(on);
     modified = true;
 }
 
@@ -640,7 +639,7 @@ void ArpWidget::doStoreParams(int ix)
 
 void ArpWidget::doRestoreParams(int ix)
 {
-    midiWorker->applyPendingParChanges();
+    midiArp->applyPendingParChanges();
     if (parStore->list.at(ix).empty) return;
     patternText->setText(parStore->list.at(ix).pattern);
     repeatPatternThroughChord->setCurrentIndex(parStore->list.at(ix).repeatMode);
@@ -652,34 +651,33 @@ void ArpWidget::doRestoreParams(int ix)
         randomLength->setValue(parStore->list.at(ix).rndLen);
         randomVelocity->setValue(parStore->list.at(ix).rndVel);
     }
-    midiWorker->advancePatternIndex(true);
+    midiArp->advancePatternIndex(true);
 }
 
 void ArpWidget::handleController(int ccnumber, int channel, int value)
 {
-    bool m;
-    int min, max, sval;
     QVector<MidiCC> cclist= midiControl->ccList;
 
     for (int l2 = 0; l2 < cclist.count(); l2++) {
-        min = cclist.at(l2).min;
-        max = cclist.at(l2).max;
+        int min = cclist.at(l2).min;
+        int max = cclist.at(l2).max;
 
         if ((ccnumber == cclist.at(l2).ccnumber) &&
             (channel == cclist.at(l2).channel)) {
+            int sval = 0;
             switch (cclist.at(l2).ID) {
                 case 0: if (min == max) {
                             if (value == max) {
-                                m = midiWorker->isMuted;
-                                midiWorker->setMuted(!m);
+                                bool m = midiArp->isMuted;
+                                midiArp->setMuted(!m);
                             }
                         }
                         else {
                             if (value == max) {
-                                midiWorker->setMuted(false);
+                                midiArp->setMuted(false);
                             }
                             if (value == min) {
-                                midiWorker->setMuted(true);
+                                midiArp->setMuted(true);
                             }
                         }
                 break;
@@ -707,30 +705,26 @@ void ArpWidget::handleController(int ccnumber, int channel, int value)
     }
 }
 
+
 void ArpWidget::updateDisplay()
 {
-    int frame = 1;
-    if (getGrooveIndex() == 0 
-            || getGrooveIndex() == midiWorker->nPoints) {
-        frame = 0;
-    }
-    parStore->updateDisplay(frame, false);
+    parStore->updateDisplay(getFramePtr() , false);
 
     screen->updateDraw();
     midiControl->update();
 
-    if (!(needsGUIUpdate || midiWorker->needsGUIUpdate)) return;
+    if (!(needsGUIUpdate || midiArp->needsGUIUpdate)) return;
 
-    muteOut->setChecked(midiWorker->isMuted);
-    screen->newGrooveValues(midiWorker->newGrooveTick, midiWorker->grooveVelocity,
-                midiWorker->grooveLength);    
-    screen->setMuted(midiWorker->isMuted);
-    parStore->ndc->setMuted(midiWorker->isMuted);
+    muteOut->setChecked(midiArp->isMuted);
+    screen->newGrooveValues(midiArp->newGrooveTick, midiArp->grooveVelocity,
+                midiArp->grooveLength);    
+    screen->setMuted(midiArp->isMuted);
+    parStore->ndc->setMuted(midiArp->isMuted);
     if (patternPresetBoxIndex != patternPresetBox->currentIndex())
         selectPatternPreset(patternPresetBoxIndex);
 
     needsGUIUpdate = false;
-    midiWorker->needsGUIUpdate = false;
+    midiArp->needsGUIUpdate = false;
 }
 
 #endif
