@@ -3,7 +3,7 @@
  * @brief Member definitions for the ArpWidget GUI class.
  *
  *
- *      Copyright 2009 - 2016 <qmidiarp-devel@lists.sourceforge.net>
+ *      Copyright 2009 - 2017 <qmidiarp-devel@lists.sourceforge.net>
  *
  *      This program is free software; you can redistribute it and/or modify
  *      it under the terms of the GNU General Public License as published by
@@ -24,21 +24,8 @@
 #ifndef ARPWIDGET_H
 #define ARPWIDGET_H
 
-#include <QString>
-#include <QTextStream>
-#include <QToolButton>
-#include <QPushButton>
-#include <QAction>
-#include <QComboBox>
-#include <QGroupBox>
-#include <QSpinBox>
-#include <QLabel>
 #include <QLineEdit>
-#include <QCheckBox>
-#include <QXmlStreamReader>
-#include <QXmlStreamWriter>
 
-#include "main.h"
 #include "midiarp.h"
 #include "inoutbox.h"
 #include "slider.h"
@@ -57,7 +44,7 @@ class ArpWidget :  public InOutBox
 {
   Q_OBJECT
 
-    MidiArp *midiWorker;
+    MidiArp *midiArp;
 
     QGroupBox *randomBox, *envelopeBox;
     QToolButton *textEditButton, *textStoreButton, *textRemoveButton;
@@ -73,7 +60,7 @@ class ArpWidget :  public InOutBox
  * @brief Constructor for ArpWidget. It creates the GUI and an ArpScreen
  * instance.
  *
- * @param p_midiWorker Associated MidiArp Object
+ * @param p_midiArp Associated MidiArp Object
  * @param p_globStore The Application-wide globStore widget
  * @param portCount Number of available MIDI output ports
  * @param compactStyle If set to True, Widget will use reduced spacing and small fonts
@@ -81,7 +68,7 @@ class ArpWidget :  public InOutBox
  * @param inOutVisible Add the module with visible InOutBox or not
  * @param name The name of the module preceded by its type (Arp: , etc...)
  */
-    ArpWidget(MidiArp *p_midiWorker, GlobStore *p_globStore,
+    ArpWidget(MidiArp *p_midiArp, GlobStore *p_globStore,
             int portCount, bool compactStyle,
             bool mutedAdd = false, bool inOutVisible = true,
             const QString& name = "");
@@ -137,8 +124,8 @@ class ArpWidget :  public InOutBox
     void handleController(int ccnumber, int channel, int value);
 #endif
 
-    int getNextTick() { return midiWorker->nextTick; }
-
+    void updateCursorPos() { screen->updateCursor(midiArp->getFramePtr()); }
+    
 /* SIGNALS */
   signals:
 /*! @brief Emitted to MainWindow::updatePatternPresets saving and deploying modified preset
@@ -177,8 +164,6 @@ class ArpWidget :  public InOutBox
   * Will cause notes remaining in MidiArp::latchBuffer until new
   * stakato note received */
     void setLatchMode(bool);
-
-    int getGrooveIndex() { return midiWorker->getGrooveIndex(); }
 };
 
 #endif
