@@ -3,7 +3,7 @@
  * @brief Implements the the LV2 GUI for the QMidiArp Arp plugin.
  *
  *
- *      Copyright 2009 - 2016 <qmidiarp-devel@lists.sourceforge.net>
+ *      Copyright 2009 - 2017 <qmidiarp-devel@lists.sourceforge.net>
  *
  *      This program is free software; you can redistribute it and/or modify
  *      it under the terms of the GNU General Public License as published by
@@ -162,7 +162,7 @@ void ArpWidgetLV2::port_event ( uint32_t port_index,
                     chIn->setCurrentIndex(fValue);
             break;
             case CURSOR_POS:
-                    screen->updateScreen((int)fValue);
+                    screen->updateCursor((int)fValue);
                     screen->update();
             break;
             case PATTERN_PRESET:
@@ -327,7 +327,7 @@ void ArpWidgetLV2::updatePattern(const QString& p_pattern)
                 ;
         }
     }
-    screen->updateScreen(pattern, minOctave, maxOctave, minStepWidth,
+    screen->updateData(pattern, minOctave, maxOctave, minStepWidth,
                     nsteps, patternMaxIndex);
     screen->update();
 }
