@@ -3,7 +3,7 @@
  * @brief Header for the Cursor class
  *
  *
- *      Copyright 2009 - 2016 <qmidiarp-devel@lists.sourceforge.net>
+ *      Copyright 2009 - 2017 <qmidiarp-devel@lists.sourceforge.net>
  *
  *      This program is free software; you can redistribute it and/or modify
  *      it under the terms of the GNU General Public License as published by
@@ -25,13 +25,9 @@
 #define CURSOR_H
 
 #include <QWidget>
-#include <QString>
-#include <QLabel>
 #include <QSizePolicy>
 #include <QSize>
 
-#include "midilfo.h"
-
 #define CSR_MIN_W   250
 #define CSR_MIN_H     6
 #define CSR_VMARG    10
