@@ -3,7 +3,7 @@
  * @brief Implementation of the Engine class
  *
  *
- *      Copyright 2009 - 2016 <qmidiarp-devel@lists.sourceforge.net>
+ *      Copyright 2009 - 2017 <qmidiarp-devel@lists.sourceforge.net>
  *
  *      This program is free software; you can redistribute it and/or modify
  *      it under the terms of the GNU General Public License as published by
@@ -22,11 +22,7 @@
  *
  */
 
-#include <QString>
-
 #include <iostream>
-
-#include "seqdriver.h"
 #include "engine.h"
 
 
@@ -65,6 +61,7 @@ Engine::Engine(GlobStore *p_globStore, GrooveWidget *p_grooveWidget,
         driver = new JackDriver(portCount, this, tr_state_cb, 
                 midi_event_received_callback, tick_callback, tempo_callback);
     }
+#ifdef HAVE_ALSA
     else {
     // In case of ALSA MIDI with Jack Transport sync, JackDriver is 
     // instantiated with 0 ports
@@ -74,6 +71,7 @@ Engine::Engine(GlobStore *p_globStore, GrooveWidget *p_grooveWidget,
         driver = new SeqDriver(jackSync, portCount, this, 
                 midi_event_received_callback, tick_callback);
     }
+#endif
 
     midiLearnFlag = false;
     midiControllable = true;
@@ -91,8 +89,6 @@ Engine::Engine(GlobStore *p_globStore, GrooveWidget *p_grooveWidget,
 
     restoreRequest = -1;
     restoreModIx = 0;
-    restoreModType = 'X';
-    restoreModWindowIndex = -1;
     restoreTick = -1;
     schedRestoreLocation = -1;
 
@@ -189,12 +185,16 @@ void Engine::setGrooveLength(int val)
     modified = true;
 }
 
-void Engine::sendGroove()
+void Engine::sendGroove(int ix)
 {
-    for (int l1 = 0; l1 < moduleWindowCount(); l1++) {
-        ((InOutBox *)moduleWindow(l1)->widget())
-            ->newGrooveValues(grooveTick, grooveVelocity, grooveLength);
-    }
+    if (ix  == -1)
+        for (int l1 = 0; l1 < moduleWindowCount(); l1++) {
+            ((InOutBox *)moduleWindow(l1)->widget())
+                ->newGrooveValues(grooveTick, grooveVelocity, grooveLength);
+        }
+    else
+        ((InOutBox *)moduleWindow(ix)->widget())
+                ->newGrooveValues(grooveTick, grooveVelocity, grooveLength);
 }
 
 //LFO handling
@@ -302,6 +302,9 @@ SeqWidget *Engine::seqWidget(int index)
 void Engine::addModuleWindow(QDockWidget *moduleWindow)
 {
     moduleWindowList.append(moduleWindow);
+    sendGroove(moduleWindowCount() - 1);
+    updateGlobRestoreTimeModule(restoreModIx);
+
     modified = true;
 }
 
@@ -369,12 +372,14 @@ void Engine::setCompactStyle(bool on)
 {
     int l1;
     if (on) {
-        for (l1 = 0; l1 < moduleWindowCount(); l1++)
+        for (l1 = 0; l1 < moduleWindowCount(); l1++) {
             moduleWindow(l1)->setStyleSheet(COMPACT_STYLE);
+        }
     }
     else {
-        for (l1 = 0; l1 < moduleWindowCount(); l1++)
+        for (l1 = 0; l1 < moduleWindowCount(); l1++) {
             moduleWindow(l1)->setStyleSheet("");
+        }
     }
 }
 
@@ -399,6 +404,7 @@ void Engine::setModified(bool m)
     modified = m;
 
     for (int l1 = 0; l1 < moduleWindowCount(); l1++) {
+        ((InOutBox *)moduleWindow(l1)->widget())->needsGUIUpdate = false;
         ((InOutBox *)moduleWindow(l1)->widget())->setModified(m);
     }
 
@@ -424,10 +430,9 @@ int Engine::getClientId()
 
 void Engine::setStatus(bool on)
 {
-    int l1;
     if (!moduleWindowCount()) return;
     if (!on) {
-        for (l1 = 0; l1 < midiArpCount(); l1++) {
+        for (int l1 = 0; l1 < midiArpCount(); l1++) {
             midiArp(l1)->clearNoteBuffer();
         }
     }
@@ -448,11 +453,8 @@ void Engine::echoCallback(bool echo_from_trig)
 {
     int l1, l2;
     int tick = driver->getCurrentTick();
-    int note_tick = 0;
     int length;
     int outport;
-    int frameptr;
-    int percent;
     bool restoreFlag = (restoreRequest >= 0);
     MidiEvent outEv;
 
@@ -465,17 +467,18 @@ void Engine::echoCallback(bool echo_from_trig)
 
     //LFO data request and queueing
     //add 8 ticks to startoff condition to cope with initial sync imperfections
-    if (((tick + 8) >= nextMinLfoTick) && (midiLfoCount())) {
+    if ((tick + 8) >= nextMinLfoTick && midiLfoCount()) {
         for (l1 = 0; l1 < midiLfoCount(); l1++) {
             if ((echo_from_trig && midiLfo(l1)->gotKbdTrig)
                     || (!midiLfo(l1)->gotKbdTrig && !echo_from_trig)) {
                 if ((tick + 8) >= midiLfo(l1)->nextTick) {
+                    lfoWidget(l1)->updateCursorPos();
+                    lfoWidget(l1)->updateIndicators();
+                    midiLfo(l1)->getNextFrame(tick);
+                    lfoWidget(l1)->checkIfRestore(&restoreTick, &restoreFlag);
                     outEv.type = EV_CONTROLLER;
                     outEv.data = midiLfo(l1)->ccnumber;
                     outEv.channel = midiLfo(l1)->channelOut;
-                    frameptr = midiLfo(l1)->getFramePtr();
-                    lfoWidget(l1)->cursor->updatePosition(frameptr);
-                    midiLfo(l1)->getNextFrame(tick);
                     outport = midiLfo(l1)->portOut;
                     l2 = 0;
                     while (midiLfo(l1)->frame.at(l2).value > -1) {
@@ -486,17 +489,6 @@ void Engine::echoCallback(bool echo_from_trig)
                         }
                         l2++;
                     }
-                    frameptr = midiLfo(l1)->getFramePtr();
-                    percent = frameptr * 100 / (midiLfo(l1)->nPoints);
-                    lfoWidget(l1)->parStore->ndc->updatePercent(percent);
-                    if ((restoreModType == 'L') && (l1 == restoreModIx)
-                            && (!globStoreWidget->timeModeBox->currentIndex())) {
-                        globStoreWidget->indicator->updatePercent(percent);
-                        if (!frameptr && restoreFlag) {
-                            restoreTick = midiLfo(l1)->frame.at(l2).tick;
-                            restoreFlag = false;
-                        }
-                    }
                 }
             }
             if (!l1)
@@ -509,33 +501,23 @@ void Engine::echoCallback(bool echo_from_trig)
 
     //Seq notes data request and queueing
     //add 8 ticks to startoff condition to cope with initial sync imperfections
-    if (((tick + 8) >= nextMinSeqTick) && (midiSeqCount())) {
+    if ((tick + 8) >= nextMinSeqTick && midiSeqCount()) {
         for (l1 = 0; l1 < midiSeqCount(); l1++) {
             if ((echo_from_trig && midiSeq(l1)->gotKbdTrig)
                     || (!midiSeq(l1)->gotKbdTrig && !echo_from_trig)) {
                 if ((tick + 8) >= midiSeq(l1)->nextTick) {
+                    seqWidget(l1)->updateCursorPos();
+                    seqWidget(l1)->updateIndicators();
+                    midiSeq(l1)->getNextFrame(tick);
+                    seqWidget(l1)->checkIfRestore(&restoreTick, &restoreFlag);
                     outEv.type = EV_NOTEON;
                     outEv.value = midiSeq(l1)->vel;
                     outEv.channel = midiSeq(l1)->channelOut;
-                    seqWidget(l1)->cursor->updatePosition(midiSeq(l1)->getCurrentIndex());
-
-                    midiSeq(l1)->getNextNote(&seqSample, tick);
                     length = midiSeq(l1)->notelength;
                     outport = midiSeq(l1)->portOut;
-                    if ((!midiSeq(l1)->isMuted) && (!seqSample.muted)) {
-                        outEv.data = seqSample.value;
-                        driver->sendMidiEvent(outEv, seqSample.tick, outport, length);
-                    }
-                        frameptr = midiSeq(l1)->getCurrentIndex();
-                        percent = frameptr * 100 / (midiSeq(l1)->nPoints);
-                        seqWidget(l1)->parStore->ndc->updatePercent(percent);
-                    if ((restoreModType == 'S') && (l1 == restoreModIx)
-                          && (!globStoreWidget->timeModeBox->currentIndex())) {
-                        globStoreWidget->indicator->updatePercent(percent);
-                        if (!frameptr && restoreFlag) {
-                            restoreTick = midiSeq(l1)->nextTick;
-                            restoreFlag = false;
-                        }
+                    if ((!midiSeq(l1)->isMuted) && (!midiSeq(l1)->returnNote.muted)) {
+                        outEv.data = midiSeq(l1)->returnNote.value;
+                        driver->sendMidiEvent(outEv, midiSeq(l1)->returnNote.tick, outport, length);
                     }
                 }
             }
@@ -553,38 +535,24 @@ void Engine::echoCallback(bool echo_from_trig)
             if ((echo_from_trig && midiArp(l1)->gotKbdTrig)
                     || (!midiArp(l1)->gotKbdTrig && !echo_from_trig)) {
                 if ((tick + 8) >= midiArp(l1)->nextTick) {
+                    arpWidget(l1)->updateCursorPos();
+                    arpWidget(l1)->updateIndicators();
+                    midiArp(l1)->getNextFrame(tick + schedDelayTicks);
+                    arpWidget(l1)->checkIfRestore(&restoreTick, &restoreFlag);
                     outEv.type = EV_NOTEON;
                     outEv.channel = midiArp(l1)->channelOut;
-                    midiArp(l1)->newRandomValues();
-                    midiArp(l1)->prepareCurrentNote(tick + schedDelayTicks);
-                    note_tick = midiArp(l1)->returnTick;
                     length = midiArp(l1)->returnLength * 4;
+                    int note_tick = midiArp(l1)->returnTick;
                     outport = midiArp(l1)->portOut;
-                    arpWidget(l1)->screen->updateScreen(midiArp(l1)->getGrooveIndex());
-                    if (midiArp(l1)->hasNewNotes && !midiArp(l1)->returnNote.isEmpty()
-                        && midiArp(l1)->returnVelocity.at(0)) {
+                    if (midiArp(l1)->hasNewNotes && midiArp(l1)->returnVelocity[0]) {
                         l2 = 0;
-                        while(midiArp(l1)->returnNote.at(l2) >= 0) {
-                            outEv.data = midiArp(l1)->returnNote.at(l2);
-                            outEv.value = midiArp(l1)->returnVelocity.at(l2);
+                        while(midiArp(l1)->returnNote[l2] >= 0) {
+                            outEv.data = midiArp(l1)->returnNote[l2];
+                            outEv.value = midiArp(l1)->returnVelocity[l2];
                             driver->sendMidiEvent(outEv, note_tick, outport, length);
                             l2++;
                         }
                     }
-                    frameptr = midiArp(l1)->getGrooveIndex();
-                    if (midiArp(l1)->nPoints)
-                        percent = (frameptr - 1) * 100 / (midiArp(l1)->nPoints);
-                    else
-                        percent = 0;
-                    arpWidget(l1)->parStore->ndc->updatePercent(percent);
-                    if ((restoreModType == 'A') && (l1 == restoreModIx)
-                            && (!globStoreWidget->timeModeBox->currentIndex())) {
-                        globStoreWidget->indicator->updatePercent(percent);
-                        if ((!frameptr || (frameptr == midiArp(l1)->nPoints)) && restoreFlag) {
-                            restoreTick = note_tick;
-                            restoreFlag = false;
-                        }
-                    }
                 }
             }
             if (!l1)
@@ -598,7 +566,7 @@ void Engine::echoCallback(bool echo_from_trig)
     }
 
     if (restoreFlag && (globStoreWidget->timeModeBox->currentIndex())) {
-        percent = 100 * (currentTick - requestTick) / (restoreTick - requestTick);
+        int percent = 100 * (currentTick - requestTick) / (restoreTick - requestTick);
         globStoreWidget->indicator->updatePercent(percent);
     }
 
@@ -607,7 +575,6 @@ void Engine::echoCallback(bool echo_from_trig)
         && (!midiLfoCount() || (nextMinLfoTick + schedDelayTicks >= restoreTick))
         && (!midiSeqCount() || (nextMinSeqTick + schedDelayTicks >= restoreTick))) {
         restoreTick = -1;
-        restoreFlag = false;
         // TODO: At term the following should be restore() instead of
         // schedRestore(). restore is not yet fit for realtime. But
         // testing seems positive this way.
@@ -622,10 +589,10 @@ bool Engine::midi_event_received_callback(void * context, MidiEvent ev)
 
 bool Engine::eventCallback(MidiEvent inEv)
 {
-    bool unmatched;
+    bool unmatched = true;
     bool no_collision = false;
     int l1;
-    unmatched = true;
+
     int tick = driver->getCurrentTick();
 
     if (sendLogEvents) {
@@ -680,7 +647,15 @@ bool Engine::eventCallback(MidiEvent inEv)
         }
     }
     for (l1 = 0; l1 < midiArpCount(); l1++) {
-        unmatched = midiArp(l1)->handleEvent(inEv, tick, 1);
+        /* In case transport is stopped we cause note off events
+         * to remove the note from the buffer (ignoring the Release 
+         * time */
+        if (!status) {
+            unmatched = midiArp(l1)->handleEvent(inEv, tick, 0);
+        }
+        else {
+            unmatched = midiArp(l1)->handleEvent(inEv, tick, 1);
+        }
         if (midiArp(l1)->gotKbdTrig) {
             nextMinArpTick = midiArp(l1)->nextTick;
             no_collision = driver->requestEchoAt(nextMinArpTick, true);
@@ -909,10 +884,12 @@ void Engine::removeParStores(int ix)
 
 void Engine::updateGlobRestoreTimeModule(int windowIndex)
 {
-    restoreModType = globStoreWidget->timeModuleBox
-                        ->itemText(windowIndex).at(0);
+    ((InOutBox *)moduleWindow(restoreModIx)->widget())
+            ->parStore->isRestoreMaster = false;
+    ((InOutBox *)moduleWindow(windowIndex)->widget())
+            ->parStore->isRestoreMaster = true;
 
-    restoreModIx = ((InOutBox *)moduleWindow(windowIndex)->widget())->ID;
+    restoreModIx = windowIndex;
 }
 
 void Engine::updateDisplay()
