@@ -3,7 +3,7 @@
  * @brief Header file for the Engine class
  *
  *
- *      Copyright 2009 - 2016 <qmidiarp-devel@lists.sourceforge.net>
+ *      Copyright 2009 - 2017 <qmidiarp-devel@lists.sourceforge.net>
  *
  *      This program is free software; you can redistribute it and/or modify
  *      it under the terms of the GNU General Public License as published by
@@ -24,20 +24,16 @@
 #ifndef ENGINE_H
 #define ENGINE_H
 
-#include <QThread>
 #include <QDockWidget>
-#include <QList>
-#include "seqdriver.h"
+#include <QThread>
+
 #include "jackdriver.h"
-#include "midiarp.h"
+#include "seqdriver.h"
 #include "arpwidget.h"
-#include "midilfo.h"
 #include "lfowidget.h"
-#include "midicontrol.h"
-#include "midiseq.h"
 #include "seqwidget.h"
 #include "groovewidget.h"
-#include "globstore.h"
+#include "config.h"
 
 /*!
  * @brief 5ms timer calling the updateDisplay() function periodically
@@ -99,13 +95,10 @@ class Engine : public QObject  {
     bool midiLearnFlag;
     bool useMidiClock;
 
-    int restoreModIx;
-    QChar restoreModType;
-    int restoreModWindowIndex;
     int restoreRequest;
-    int restoreModule;
     int restoreTick;
     int schedRestoreLocation; /**< When Engine requests restore during running this is the location, it is -1 otherwise */
+
     double tempo;
     double requestedTempo;
 
@@ -116,7 +109,6 @@ class Engine : public QObject  {
     int nextMinArpTick;
     int currentTick;
     int requestTick;
-    Sample seqSample;
     bool sendLogEvents;
     int logEventCount;
     QVector<MidiEvent> logEventBuffer;
@@ -130,6 +122,7 @@ class Engine : public QObject  {
     static void tempo_callback(double bpm, void *context);
   public:
     int grooveTick, grooveVelocity, grooveLength;
+    int restoreModIx;
     bool midiControllable;
     bool status;
     bool ready;
@@ -181,7 +174,7 @@ class Engine : public QObject  {
 
     int getClientId();
     void setTempo(double bpm);
-    void sendGroove();
+    void sendGroove(int ix = -1);
     void showAllIOPanels(bool on);
 
   signals:
