@@ -3,7 +3,7 @@
  * @brief Implements the GlobStore UI class.
  *
  *
- *      Copyright 2009 - 2016 <qmidiarp-devel@lists.sourceforge.net>
+ *      Copyright 2009 - 2017 <qmidiarp-devel@lists.sourceforge.net>
  *
  *      This program is free software; you can redistribute it and/or modify
  *      it under the terms of the GNU General Public License as published by
@@ -89,22 +89,23 @@ GlobStore::GlobStore(QWidget *parent)
     QAction* removeStoreAction = new QAction(tr("&Remove"), this);
     QToolButton *removeStoreButton = new QToolButton;
     removeStoreButton->setDefaultAction(removeStoreAction);
-    removeStoreButton->setFixedSize(50, 20);
+    removeStoreButton->setFixedSize(60, 20);
     removeStoreButton->setArrowType (Qt::ArrowType(1));
     connect(removeStoreAction, SIGNAL(triggered()), this, SLOT(removeLocation()));
 
     QToolButton *toolButton = new QToolButton;
     toolButton->setText("Global");
-    toolButton->setMinimumSize(QSize(48,40));
+    toolButton->setMinimumSize(QSize(56,32));
     midiControl->addMidiLearnMenu("GlobRestore", toolButton, 0);
+    
     QFrame *topRow = new QFrame;
-
-    QHBoxLayout *topRowLayout = new QHBoxLayout;
+    QVBoxLayout *topRowLayout = new QVBoxLayout;
     topRowLayout->addWidget(toolButton);
+    topRowLayout->addStretch();
     topRowLayout->setSpacing(0);
     topRowLayout->setMargin(0);
     topRow->setFrameStyle(QFrame::StyledPanel);
-    topRow->setMinimumSize(QSize(48,46));;
+    topRow->setMinimumSize(QSize(48,48));;
     topRow->setLayout(topRowLayout);
 
     QVBoxLayout *buttonLayout = new QVBoxLayout;
@@ -113,7 +114,7 @@ GlobStore::GlobStore(QWidget *parent)
     QVBoxLayout *columnLayout = new QVBoxLayout;
     columnLayout->addLayout(buttonLayout);
     columnLayout->addWidget(removeStoreButton);
-    columnLayout->addStretch();
+    columnLayout->addStretch(1);
 
     indivButtonLayout = new QHBoxLayout;
     indivButtonLayout->setSpacing(0);
@@ -128,6 +129,7 @@ GlobStore::GlobStore(QWidget *parent)
     QVBoxLayout *centLayout = new QVBoxLayout;
     centLayout->addLayout(upperRowLayout);
     centLayout->addLayout(secondRowLayout);
+    centLayout->addStretch(1);
 
     addLocation();
 
@@ -168,7 +170,7 @@ void GlobStore::addLocation()
     restoreButton->setDefaultAction(restoreAction);
     restoreButton->setFixedSize(45, 25);
     restoreAction->setText(QString::number(widgetList.count() + 1));
-    restoreAction->setFont(QFont("Helvetica", 18));
+    restoreButton->setStyleSheet("font: 18pt");
     restoreAction->setDisabled(true);
     restoreAction->setObjectName("-1");
     restoreAction->setProperty("index", widgetList.count() + 1);
@@ -239,15 +241,12 @@ void GlobStore::requestDispState(int ix, int selected)
 
 void GlobStore::setDispState(int ix, int selected)
 {
-    int start, end;
-    int l1, l2;
-
-    start = 1;
-    end = timeModuleBox->count();
+    int start = 1;
+    int end = timeModuleBox->count();
 
     if (selected == 1) {
-        for (l1 = start; l1 <= end; l1++) {
-            for (l2 = 1; l2 < widgetList.count(); l2++) {
+        for (int l1 = start; l1 <= end; l1++) {
+            for (int l2 = 1; l2 < widgetList.count(); l2++) {
                 setBGColorAt(l1, l2 , 0);
             }
             setBGColorAt(l1, ix + 1, 1);
@@ -255,7 +254,7 @@ void GlobStore::setDispState(int ix, int selected)
         activeStore = ix;
     }
     else if (selected == 2) {
-        for (l1 = start; l1 <= end; l1++) {
+        for (int l1 = start; l1 <= end; l1++) {
             setBGColorAt(l1, ix + 1, 2);
             if (currentRequest != activeStore) {
                 setBGColorAt(l1, currentRequest + 1, 0);
@@ -361,6 +360,23 @@ void GlobStore::writeData(QXmlStreamWriter& xml)
     modified = false;
 }
 
+void GlobStore::skipXmlElement(QXmlStreamReader& xml)
+{
+    if (xml.isStartElement()) {
+        qWarning("Unknown Element in XML File: %s",qPrintable(xml.name().toString()));
+        while (!xml.atEnd()) {
+            xml.readNext();
+
+            if (xml.isEndElement())
+                break;
+
+            if (xml.isStartElement()) {
+                skipXmlElement(xml);
+            }
+        }
+    }
+}
+
 void GlobStore::handleController(int ccnumber, int channel, int value)
 {
     if (!midiControl->ccList.count()) return;
