@@ -3,7 +3,7 @@
  * @brief Headers for the GlobStore UI class.
  *
  *
- *      Copyright 2009 - 2016 <qmidiarp-devel@lists.sourceforge.net>
+ *      Copyright 2009 - 2017 <qmidiarp-devel@lists.sourceforge.net>
  *
  *      This program is free software; you can redistribute it and/or modify
  *      it under the terms of the GNU General Public License as published by
@@ -24,14 +24,12 @@
 #ifndef GLOBSTORE_H
 #define GLOBSTORE_H
 
-#include <QAction>
 #include <QBoxLayout>
 #include <QComboBox>
 #include <QDialogButtonBox>
 #include <QGridLayout>
 #include <QGroupBox>
 #include <QList>
-#include <QSignalMapper>
 #include <QString>
 
 #include "indicator.h"
@@ -109,6 +107,18 @@ class GlobStore : public QWidget
     void handleController(int ccnumber, int channel, int value);
     bool isModified() { return modified;};
     void setModified(bool on) { modified = on; };
+#ifdef APPBUILD
+/*!
+* @brief allows ignoring one XML element in the XML stream
+* passed by the caller.
+*
+* It also advances the stream read-in. It is used to
+* ignore unknown elements for both-ways-compatibility
+*
+* @param xml reference to QXmlStreamReader containing the open XML stream
+*/
+    void skipXmlElement(QXmlStreamReader& xml);
+#endif
 
   signals:
 
