@@ -3,7 +3,7 @@
  * @brief Implementation of the GrooveWidget QWidget class
  *
  *
- *      Copyright 2009 - 2016 <qmidiarp-devel@lists.sourceforge.net>
+ *      Copyright 2009 - 2017 <qmidiarp-devel@lists.sourceforge.net>
  *
  *      This program is free software; you can redistribute it and/or modify
  *      it under the terms of the GNU General Public License as published by
@@ -22,17 +22,9 @@
  *
  */
 
-#include <QString>
-#include <QLabel>
-#include <QSlider>
-#include <QBoxLayout>
-#include <QPushButton>
-#include <QComboBox>
-#include <QSpinBox>
 #include <QGroupBox>
 
 #include "groovewidget.h"
-#include "slider.h"
 
 
 GrooveWidget::GrooveWidget()
@@ -88,13 +80,12 @@ void GrooveWidget::updateGrooveLength(int val)
 }
 void GrooveWidget::handleController(int ccnumber, int channel, int value)
 {
-    int min, max, sval;
     QVector<MidiCC> cclist= midiControl->ccList;
 
     for (int l2 = 0; l2 < cclist.count(); l2++) {
-        min = cclist.at(l2).min;
-        max = cclist.at(l2).max;
-        sval = min + ((double)value * (max - min) / 127);
+        int min = cclist.at(l2).min;
+        int max = cclist.at(l2).max;
+        int sval = min + ((double)value * (max - min) / 127);
         if ((ccnumber == cclist.at(l2).ccnumber) &&
             (channel == cclist.at(l2).channel)) {
             switch (cclist.at(l2).ID) {
@@ -149,17 +140,6 @@ void GrooveWidget::writeData(QXmlStreamWriter& xml)
     xml.writeEndElement();
 }
 
-void GrooveWidget::updateDisplay()
-{
-    midiControl->update();
-    if (!needsGUIUpdate) return;
-
-    grooveTick->setValue(tickVal);
-    grooveVelocity->setValue(velocityVal);
-    grooveLength->setValue(lengthVal);
-
-}
-
 void GrooveWidget::skipXmlElement(QXmlStreamReader& xml)
 {
     if (xml.isStartElement()) {
@@ -176,3 +156,14 @@ void GrooveWidget::skipXmlElement(QXmlStreamReader& xml)
         }
     }
 }
+
+void GrooveWidget::updateDisplay()
+{
+    midiControl->update();
+    if (!needsGUIUpdate) return;
+
+    grooveTick->setValue(tickVal);
+    grooveVelocity->setValue(velocityVal);
+    grooveLength->setValue(lengthVal);
+
+}
