@@ -3,7 +3,7 @@
  * @brief Member definitions for the GrooveWidget QWidget class.
  *
  *
- *      Copyright 2009 - 2016 <qmidiarp-devel@lists.sourceforge.net>
+ *      Copyright 2009 - 2017 <qmidiarp-devel@lists.sourceforge.net>
  *
  *      This program is free software; you can redistribute it and/or modify
  *      it under the terms of the GNU General Public License as published by
@@ -24,15 +24,9 @@
 #ifndef GROOVEWIDGET_H
 #define GROOVEWIDGET_H
 
-#include <QString>
-#include <QLabel>
-#include <QSlider>
 #include <QBoxLayout>
 #include <QComboBox>
 #include <QCheckBox>
-#include <QSpinBox>
-#include <QXmlStreamReader>
-#include <QXmlStreamWriter>
 #include "slider.h"
 #include "midicontrol.h"
 
@@ -74,7 +68,18 @@ class GrooveWidget : public QWidget
 * @param xml QXmlStreamWriter to write to
 */
     void writeData(QXmlStreamWriter& xml);
+#ifdef APPBUILD
+/*!
+* @brief allows ignoring one XML element in the XML stream
+* passed by the caller.
+*
+* It also advances the stream read-in. It is used to
+* ignore unknown elements for both-ways-compatibility
+*
+* @param xml reference to QXmlStreamReader containing the open XML stream
+*/
     void skipXmlElement(QXmlStreamReader& xml);
+#endif
 
   signals:
     void newGrooveVelocity(int);
