@@ -3,7 +3,7 @@
  * @brief Implements the InOutBox GUI class
  *
  *
- *      Copyright 2009 - 2016 <qmidiarp-devel@lists.sourceforge.net>
+ *      Copyright 2009 - 2017 <qmidiarp-devel@lists.sourceforge.net>
  *
  *      This program is free software; you can redistribute it and/or modify
  *      it under the terms of the GNU General Public License as published by
@@ -21,17 +21,11 @@
  *      MA 02110-1301, USA.
  */
 
-#include <QBoxLayout>
-
 #include "inoutbox.h"
 #include "config.h"
 
 #ifdef APPBUILD
 
-#include <QMessageBox>
-#include <QInputDialog>
-
-
 #include "pixmaps/lfowavcp.xpm"
 #include "pixmaps/seqwavcp.xpm"
 #include "pixmaps/arpremove.xpm"
@@ -150,6 +144,8 @@ InOutBox::InOutBox(bool compactStyle,
     chIn = new QComboBox;
     int l1;
     for (l1 = 0; l1 < 16; l1++) chIn->addItem(QString::number(l1 + 1));
+    chIn->addItem("Omni");
+    chIn->setCurrentIndex(OMNI);
     chInLabel->setBuddy(chIn);
 
     inputFilterBox = new QGroupBox(tr("Note Filter"));
@@ -235,7 +231,7 @@ InOutBox::InOutBox(bool compactStyle,
     channelOut = new QComboBox;
     channelLabel->setBuddy(channelOut);
     for (l1 = 0; l1 < 16; l1++) channelOut->addItem(QString::number(l1 + 1));
-
+    
     QGridLayout *portBoxLayout = new QGridLayout;
     portBoxLayout->addWidget(ccnumberLabel, 0, 0);
     portBoxLayout->addWidget(ccnumberBox, 0, 1);
@@ -260,7 +256,6 @@ InOutBox::InOutBox(bool compactStyle,
     muteOutAction->setCheckable(true);
     muteOut = new QToolButton;
     muteOut->setDefaultAction(muteOutAction);
-    muteOut->setFont(QFont("Helvetica", 8));
     muteOut->setMinimumSize(QSize(35,20));
     connect(muteOutAction, SIGNAL(toggled(bool)), this, 
             SLOT(setMuted(bool)));
@@ -284,12 +279,13 @@ InOutBox::InOutBox(bool compactStyle,
     hideInOutBoxButton->setArrowType (Qt::ArrowType(0));
 
 #ifdef APPBUILD
-        parStore = new ParStore(globStore, name, muteOutAction, deferChangesAction, this);
+        parStore = new ParStore(globStore, name, muteOutAction
+					, deferChangesAction, this);
         connect(parStore, SIGNAL(store(int, bool)),
                  this, SLOT(storeParams(int, bool)));
         connect(parStore, SIGNAL(restore(int)),
                  this, SLOT(restoreParams(int)));
-                 
+    if (compactStyle) parStore->setStyleSheet( COMPACT_STYLE );
     midiControl->addMidiLearnMenu("Note Low", indexIn[0], 10);
     midiControl->addMidiLearnMenu("Note Hi", indexIn[1], 11);
     midiControl->addMidiLearnMenu("MuteToggle", muteOut, 0);
@@ -315,6 +311,8 @@ InOutBox::InOutBox(bool compactStyle,
             SLOT(updateEnableVelIn(bool)));
     connect(enableNoteIn, SIGNAL(toggled(bool)), this, 
             SLOT(updateEnableNoteIn(bool)));
+    connect(enableNoteOff, SIGNAL(toggled(bool)), this, 
+            SLOT(updateEnableNoteOff(bool)));
     connect(enableRestartByKbd, SIGNAL(toggled(bool)), this, 
             SLOT(updateEnableRestartByKbd(bool)));
     connect(enableTrigByKbd, SIGNAL(toggled(bool)), this, 
@@ -352,12 +350,6 @@ InOutBox::~InOutBox()
 #endif
 }
 
-void InOutBox::setChannelOut(int value)
-{
-    channelOut->setCurrentIndex(value);
-    modified = true;
-}
-
 bool InOutBox::isModified()
 {
 	bool mcmod = false;
@@ -494,23 +486,6 @@ void InOutBox::setMuted(bool on)
     needsGUIUpdate = true;
     modified = true;
 }
-void InOutBox::setChIn(int value)
-{
-    chIn->setCurrentIndex(value);
-    modified = true;
-}
-
-void InOutBox::setIndexIn(int index, int value)
-{
-    indexIn[index]->setValue(value);
-    modified = true;
-}
-
-void InOutBox::setRangeIn(int index, int value)
-{
-    rangeIn[index]->setValue(value);
-    modified = true;
-}
 
 void InOutBox::updateDeferChanges(bool on)
 {
@@ -739,6 +714,23 @@ void InOutBox::readCommonData(QXmlStreamReader& xml)
 	}
 }
 
+void InOutBox::skipXmlElement(QXmlStreamReader& xml)
+{
+    if (xml.isStartElement()) {
+        qWarning("Unknown Element in XML File: %s",qPrintable(xml.name().toString()));
+        while (!xml.atEnd()) {
+            xml.readNext();
+
+            if (xml.isEndElement())
+                break;
+
+            if (xml.isStartElement()) {
+                skipXmlElement(xml);
+            }
+        }
+    }
+}
+
 void InOutBox::newGrooveValues(int p_grooveTick, int p_grooveVelocity,
         int p_grooveLength)
 {
@@ -747,7 +739,35 @@ void InOutBox::newGrooveValues(int p_grooveTick, int p_grooveVelocity,
     midiWorker->newGrooveTick = p_grooveTick;
     midiWorker->grooveVelocity = p_grooveVelocity;
     midiWorker->grooveLength = p_grooveLength;
-    needsGUIUpdate = true;
+    midiWorker->needsGUIUpdate = true;
+}
+
+void InOutBox::updateIndicators()
+{
+    int ci = midiWorker->getFramePtr();
+
+    int percent;
+    if (midiWorker->nPoints)
+        percent = ci * 100 / (midiWorker->nPoints);
+    else
+        percent = 0;
+    
+    parStore->ndc->updatePercent(percent);
+    
+    if (parStore->isRestoreMaster
+            && (!globStore->timeModeBox->currentIndex())) {
+        globStore->indicator->updatePercent(percent);
+    }
+}
+
+void InOutBox::checkIfRestore(int *restoreTick, bool *restoreFlag)
+{
+	if (!midiWorker->getFramePtr() && restoreFlag
+		&& parStore->isRestoreMaster
+		&& !globStore->timeModeBox->currentIndex()) {
+		*restoreTick = midiWorker->nextTick;
+		*restoreFlag = false;
+	}
 }
 
 #endif
