@@ -3,7 +3,7 @@
  * @brief Implementation of the LfoScreen class
  *
  *
- *      Copyright 2009 - 2016 <qmidiarp-devel@lists.sourceforge.net>
+ *      Copyright 2009 - 2017 <qmidiarp-devel@lists.sourceforge.net>
  *
  *      This program is free software; you can redistribute it and/or modify
  *      it under the terms of the GNU General Public License as published by
@@ -22,55 +22,31 @@
  *
  */
 
-#include <QPainter>
-#include <QPaintDevice>
-#include <QPen>
-#include <QPixmap>
-
 #include "lfoscreen.h"
 
-
-LfoScreen::LfoScreen(QWidget* parent) : QWidget (parent)
+LfoScreen::LfoScreen(QWidget* parent) : Screen (parent)
 {
     setPalette(QPalette(QColor(0, 20, 100), QColor(0, 20, 100)));
-    mouseX = 0;
-    mouseY = 0;
     xMax = LFOSCR_HMARG;
-    currentIndex = 0;
-    grooveTick = 0;
-    grooveVelocity = 0;
-    grooveLength = 0;
-    isMuted = false;
-    needsRedraw = false;
-}
-
-LfoScreen::~LfoScreen()
-{
 }
 
 // Paint event handler.
 void LfoScreen::paintEvent(QPaintEvent*)
 {
+    if (p_data.isEmpty()) return;
+
     QPainter p(this);
     QPen pen;
     pen.setWidth(1);
     p.setFont(QFont("Helvetica", 8));
     p.setPen(pen);
 
-    int l1, l2;
-    int nsteps = 0.0;
     int beat = 4;
-    int npoints = 0;
-    int ypos, xpos, xscale, yscale;
+    int xscale, yscale;
     w = QWidget::width();
     h = QWidget::height();
     int notestreak_thick = 2;
-    int ofs;
     int x, x1;
-    int beatRes = 1;
-    int beatDiv = 0;
-    int grooveTmp = 0;
-    l2 = 0;
 
     //Beryll Filled Frame
     if (isMuted)
@@ -82,18 +58,19 @@ void LfoScreen::paintEvent(QPaintEvent*)
     p.setPen(QColor(160, 20, 20));
 
     //Grid
-    if (p_data.isEmpty()) return;
-    npoints = p_data.count() - 1;
-    nsteps = p_data.at(npoints).tick / TPQN;
+    int npoints = p_data.count() - 1;
+    int nsteps = p_data.at(npoints).tick / TPQN;
     if (!nsteps) nsteps = 1;
-    beatRes = npoints / nsteps;
-    beatDiv = (npoints > 64) ? 64 / nsteps : beatRes;
+    int beatRes = npoints / nsteps;
+    int beatDiv = (npoints > 64) ? 64 / nsteps : beatRes;
     xscale = (w - 2 * LFOSCR_HMARG);
     yscale = h - 2 * LFOSCR_VMARG;
 
     //Beat separators
-    for (l1 = 0; l1 < nsteps + 1; l1++) {
-
+    for (int l1 = 0; l1 < nsteps + 1; l1++) {
+        
+        int ofs = 0;
+        
         if (l1 < 10) {
             ofs = w / nsteps * .5 - 4 + LFOSCR_HMARG;
         } else {
@@ -109,15 +86,13 @@ void LfoScreen::paintEvent(QPaintEvent*)
                 LFOSCR_HMARG + x, h-LFOSCR_VMARG);
 
         if (l1 < nsteps) {
-            p.setPen(QColor(180, 150, 100));
-
             //Beat numbers
+            p.setPen(QColor(180, 150, 100));
             p.drawText(ofs + x, LFOSCR_VMARG, QString::number(l1+1));
 
             // Beat divisor separators
             p.setPen(QColor(120, 60, 20));
-            x1 = x;
-            for (l2 = 1; l2 < beatDiv; l2++) {
+            for (int l2 = 1; l2 < beatDiv; l2++) {
                 x1 = x + l2 * xscale / nsteps / beatDiv;
                 if (x1 < xscale)
                     p.drawLine(LFOSCR_HMARG + x1,
@@ -132,14 +107,14 @@ void LfoScreen::paintEvent(QPaintEvent*)
 
     pen.setWidth(notestreak_thick);
     p.setPen(pen);
-    grooveTmp = (beatRes < 32) ? grooveTick : 0;
-    l1 = 0;
+    int grooveTmp = (beatRes < 32) ? grooveTick : 0;
+    int l1 = 0;
     while (l1 < npoints) {
 
         x = (l1 + .01 * (double)grooveTmp * (l1 % 2)) * xscale / npoints;
-        ypos = yscale - yscale * p_data.at(l1).value / 128
+        int ypos = yscale - yscale * p_data.at(l1).value / 128
                         + LFOSCR_VMARG;
-        xpos = LFOSCR_HMARG + x + pen.width() / 2;
+        int xpos = LFOSCR_HMARG + x + pen.width() / 2;
         if (p_data.at(l1).muted) {
             pen.setColor(QColor(100, 40, 5));
         }
@@ -156,8 +131,8 @@ void LfoScreen::paintEvent(QPaintEvent*)
 
     //Horizontal separators and numbers
     p.setPen(QColor(180, 120, 40));
-    for (l1 = 0; l1 < 3; l1++) {
-        ypos = yscale * l1 / 2 + LFOSCR_VMARG;
+    for (int l1 = 0; l1 < 3; l1++) {
+        int ypos = yscale * l1 / 2 + LFOSCR_VMARG;
         p.drawLine(LFOSCR_HMARG, ypos, xMax, ypos);
         p.drawText(1, yscale * (l1) + LFOSCR_VMARG + 4,
                 QString::number(128 * (1 - l1)));
@@ -165,40 +140,6 @@ void LfoScreen::paintEvent(QPaintEvent*)
 
 }
 
-void LfoScreen::updateData(const QVector<Sample>& data)
-{
-    p_data = data;
-    needsRedraw = true;
-}
-
-void LfoScreen::updateDraw()
-{
-    if (!needsRedraw) return;
-    needsRedraw = false;
-    update();
-}
-
-void LfoScreen::setMuted(bool on)
-{
-    isMuted = on;
-    needsRedraw = true;
-}
-
-void LfoScreen::mouseMoveEvent(QMouseEvent *event)
-{
-    emitMouseEvent(event, 0);
-}
-
-void LfoScreen::mousePressEvent(QMouseEvent *event)
-{
-    emitMouseEvent(event, 1);
-}
-
-void LfoScreen::mouseReleaseEvent(QMouseEvent *event)
-{
-    emitMouseEvent(event, 2);
-}
-
 void LfoScreen::emitMouseEvent(QMouseEvent *event, int pressed)
 {
     mouseX = event->x();
@@ -214,13 +155,6 @@ void LfoScreen::emitMouseEvent(QMouseEvent *event, int pressed)
                 (h - 2 * LFOSCR_VMARG), event->buttons(), pressed);
 }
 
-void LfoScreen::wheelEvent(QWheelEvent *event)
-{
-    mouseW = event->delta();
-    emit mouseWheel(mouseW / 120);
-    event->accept();
-}
-
 int LfoScreen::clip(int value, int min, int max, bool *outOfRange)
 {
     int tmp = value;
@@ -236,26 +170,8 @@ int LfoScreen::clip(int value, int min, int max, bool *outOfRange)
     return(tmp);
 }
 
-void LfoScreen::setRecordMode(bool on)
+void LfoScreen::updateData(const QVector<Sample>& data)
 {
-    recordMode = on;
-}
-
-void LfoScreen::newGrooveValues(int tick, int vel, int length)
-{
-    grooveTick = tick;
-    grooveVelocity = vel;
-    grooveLength = length;
+    p_data = data;
     needsRedraw = true;
 }
-
-QSize LfoScreen::sizeHint() const
-{
-    return QSize(LFOSCR_MIN_W, LFOSCR_MIN_H);
-}
-
-QSizePolicy LfoScreen::sizePolicy() const
-{
-    return QSizePolicy(QSizePolicy::MinimumExpanding,
-            QSizePolicy::MinimumExpanding);
-}
