@@ -3,7 +3,7 @@
  * @brief Implements the LogWidget QWidget class.
  *
  *
- *      Copyright 2009 - 2016 <qmidiarp-devel@lists.sourceforge.net>
+ *      Copyright 2009 - 2017 <qmidiarp-devel@lists.sourceforge.net>
  *
  *      This program is free software; you can redistribute it and/or modify
  *      it under the terms of the GNU General Public License as published by
@@ -21,9 +21,6 @@
  *      MA 02110-1301, USA.
  */
 
-#include <QString>
-#include <QLabel>
-#include <QSlider>
 #include <QPushButton>
 #include <QStringList>
 #include <QGroupBox>
