@@ -31,13 +31,13 @@
  * events in colors depending on their type. 
  *
  *   @section AUTHORS
- * Frank Kober 2009-2015 <BR> 
+ * Frank Kober 2009 - 2017 <BR> 
  * Nedko Arnaudov 2011 <BR> 
  * Guido Scholz 2009 <BR> 
  * Matthias Nagorni 2003 <BR> 
  * 
  *
- *      Copyright 2009 - 2016 <qmidiarp-devel@lists.sourceforge.net>
+ *      Copyright 2009 - 2017 <qmidiarp-devel@lists.sourceforge.net>
  *
  *      This program is free software; you can redistribute it and/or modify
  *      it under the terms of the GNU General Public License as published by
@@ -73,8 +73,10 @@
 static struct option options[] = {
     {"version", 0, 0, 'v'},
     {"help", 0, 0, 'h'},
+#ifdef HAVE_ALSA
     {"alsa", 0, 0, 'a'},
     {"jack", 0, 0, 'j'},
+#endif
     {"jack_session_uuid", required_argument, 0, 'U' },
     {"portCount", 1, 0, 'p'},
     {0, 0, 0, 0}
@@ -82,23 +84,6 @@ static struct option options[] = {
 
 QString global_jack_session_uuid = "";
 
-void skipXmlElement(QXmlStreamReader& xml)
-{
-    if (xml.isStartElement()) {
-        qWarning("Unknown Element in XML File: %s",qPrintable(xml.name().toString()));
-        while (!xml.atEnd()) {
-            xml.readNext();
-
-            if (xml.isEndElement())
-                break;
-
-            if (xml.isStartElement()) {
-                skipXmlElement(xml);
-            }
-        }
-    }
-}
-
 int main(int argc, char *argv[])
 {
     int getopt_return;
@@ -129,22 +114,24 @@ int main(int argc, char *argv[])
                     "Print application version" << endl;
                 out << "  -h, --help               "
                     "Print this message" << endl;
+#ifdef HAVE_ALSA
                 out << "  -a, --alsa               "
                     "Use ALSA MIDI interface" << endl;
                 out << "  -j, --jack               "
                     "Use JACK MIDI interface (default)" << endl;
+#endif
                 out << QString("  -p, --portCount <num>    "
                         "Number of output ports [%1]").arg(portCount) << endl;
                 out.flush();
                 exit(EXIT_SUCCESS);
-
+#ifdef HAVE_ALSA
             case 'a':
                 alsamidi = true;
                 break;
-
             case 'j':
                 alsamidi = false;
                 break;
+#endif
             case 'U':
                 global_jack_session_uuid = QString(optarg);
                 break;
