@@ -3,7 +3,7 @@
  * @brief Implements the MainWindow top-level UI class.
  *
  *
- *      Copyright 2009 - 2016 <qmidiarp-devel@lists.sourceforge.net>
+ *      Copyright 2009 - 2017 <qmidiarp-devel@lists.sourceforge.net>
  *
  *      This program is free software; you can redistribute it and/or modify
  *      it under the terms of the GNU General Public License as published by
@@ -26,7 +26,6 @@
 #include <QFileDialog>
 #include <QPixmap>
 #include <QInputDialog>
-#include <QMainWindow>
 #include <QMenu>
 #include <QMenuBar>
 #include <QMetaType>
@@ -34,7 +33,6 @@
 #include <QStringList>
 #include <QSpinBox>
 #include <QStyle>
-#include <QTableWidget>
 #include <QTextStream>
 #include <QXmlStreamReader>
 #include <QXmlStreamWriter>
@@ -465,8 +463,8 @@ void MainWindow::seqNew()
 void MainWindow::addArp(const QString& p_name, bool fromfile, bool inOutVisible)
 {
     int count, widgetID;
-    MidiArp *midiWorker = new MidiArp();
-    ArpWidget *moduleWidget = new ArpWidget(midiWorker, globStore,
+    MidiArp *midiArp = new MidiArp();
+    ArpWidget *moduleWidget = new ArpWidget(midiArp, globStore,
             engine->getPortCount(), passWidget->compactStyle,
             passWidget->mutedAdd, inOutVisible, p_name);
     connect(moduleWidget, SIGNAL(presetsChanged(const QString&, const
@@ -491,9 +489,8 @@ void MainWindow::addArp(const QString& p_name, bool fromfile, bool inOutVisible)
         moduleWidget->storeParams(l1, true);
     }
 
-    engine->addMidiArp(midiWorker);
+    engine->addMidiArp(midiArp);
     engine->addArpWidget(moduleWidget);
-    engine->sendGroove();
 
     count = engine->moduleWindowCount();
     moduleWidget->parentDockID = count;
@@ -508,8 +505,8 @@ void MainWindow::addLfo(const QString& p_name, bool fromfile, int clonefrom, boo
 {
     int widgetID, count;
 
-    MidiLfo *midiWorker = new MidiLfo();
-    LfoWidget *moduleWidget = new LfoWidget(midiWorker, globStore,
+    MidiLfo *midiLfo = new MidiLfo();
+    LfoWidget *moduleWidget = new LfoWidget(midiLfo, globStore,
             engine->getPortCount(), passWidget->compactStyle,
             passWidget->mutedAdd, inOutVisible, p_name);
     connect(moduleWidget, SIGNAL(moduleRemove(int)),
@@ -537,15 +534,14 @@ void MainWindow::addLfo(const QString& p_name, bool fromfile, int clonefrom, boo
     }
 
     if (clonefrom >= 0) {
-        midiWorker->reverse = engine->lfoWidget(clonefrom)->getReverse();
-        midiWorker->setNextTick(engine->lfoWidget(clonefrom)->getNextTick());
+        midiLfo->reverse = engine->lfoWidget(clonefrom)->getReverse();
+        midiLfo->setNextTick(engine->lfoWidget(clonefrom)->getNextTick());
     }
     else if (engine->lfoWidgetCount())
-        midiWorker->setNextTick(engine->lfoWidget(0)->getNextTick());
+        midiLfo->setNextTick(engine->lfoWidget(0)->getNextTick());
 
-    engine->addMidiLfo(midiWorker);
+    engine->addMidiLfo(midiLfo);
     engine->addLfoWidget(moduleWidget);
-    engine->sendGroove();
 
     count = engine->moduleWindowCount();
     moduleWidget->parentDockID = count;
@@ -561,8 +557,8 @@ void MainWindow::addSeq(const QString& p_name, bool fromfile, int clonefrom, boo
 {
     int widgetID, count;
 
-    MidiSeq *midiWorker = new MidiSeq();
-    SeqWidget *moduleWidget = new SeqWidget(midiWorker, globStore,
+    MidiSeq *midiSeq = new MidiSeq();
+    SeqWidget *moduleWidget = new SeqWidget(midiSeq, globStore,
             engine->getPortCount(), passWidget->compactStyle,
             passWidget->mutedAdd, inOutVisible, p_name);
     connect(moduleWidget, SIGNAL(moduleRemove(int)), this, SLOT(removeSeq(int)));
@@ -587,15 +583,14 @@ void MainWindow::addSeq(const QString& p_name, bool fromfile, int clonefrom, boo
     }
 
     if (clonefrom >= 0) {
-        midiWorker->reverse = engine->seqWidget(clonefrom)->getReverse();
-        midiWorker->setNextTick(engine->seqWidget(clonefrom)->getNextTick());
+        midiSeq->reverse = engine->seqWidget(clonefrom)->getReverse();
+        midiSeq->setNextTick(engine->seqWidget(clonefrom)->getNextTick());
     }
     else if (engine->seqWidgetCount())
-        midiWorker->setNextTick(engine->seqWidget(0)->getNextTick());
+        midiSeq->setNextTick(engine->seqWidget(0)->getNextTick());
 
-    engine->addMidiSeq(midiWorker);
+    engine->addMidiSeq(midiSeq);
     engine->addSeqWidget(moduleWidget);
-    engine->sendGroove();
 
     count = engine->moduleWindowCount();
     moduleWidget->parentDockID = count;
@@ -864,11 +859,9 @@ void MainWindow::readFilePartGlobal(QXmlStreamReader& xml)
 void MainWindow::readFilePartModules(QXmlStreamReader& xml)
 {
     int count = 0;
-    bool iovis;
-
 
     while (!xml.atEnd()) {
-        iovis = true;
+        bool iovis = true;
         xml.readNext();
         if (xml.isEndElement())
             break;
@@ -929,6 +922,23 @@ void MainWindow::readFilePartGUI(QXmlStreamReader& xml)
     }
 }
 
+void MainWindow::skipXmlElement(QXmlStreamReader& xml)
+{
+    if (xml.isStartElement()) {
+        qWarning("Unknown Element in XML File: %s",qPrintable(xml.name().toString()));
+        while (!xml.atEnd()) {
+            xml.readNext();
+
+            if (xml.isEndElement())
+                break;
+
+            if (xml.isStartElement()) {
+                skipXmlElement(xml);
+            }
+        }
+    }
+}
+
 void MainWindow::fileSave()
 {
     if (filename.isEmpty())
@@ -1126,11 +1136,6 @@ void MainWindow::updateTransportStatus(bool on)
     //if (alsaMidi) tempoSpin->setDisabled(on);
 }
 
-void MainWindow::resetTransport()
-{
-    engine->setStatus(engine->status);
-}
-
 void MainWindow::midiClockToggle(bool on)
 {
     if (on) jackSyncAction->setChecked(false);
@@ -1194,6 +1199,9 @@ bool MainWindow::checkRcFile()
             <<  "Chord Oct 16 A"
             <<  "Chord Oct 16 B"
             <<  "Chord Oct 16 C"
+            <<  "Fast Chords1"
+            <<  "Fast Chords2"
+            <<  "Fast Chords3"
             <<  "Chords/Glissando 16";
 
         patternPresets
@@ -1207,6 +1215,9 @@ bool MainWindow::checkRcFile()
             << ">>////(0123456789)\\ \\ \\ +(0123456789)"
             << ">>///0\\ \\ \\ 0+////0\\ \\ \\ \\ -00+0-00+0-00+0-00+0-0"
             << ">>///0\\ \\ \\ 0+////(0123)\\ \\ \\ \\ -00+(1234)-00+0-00+0-00+0-0"
+            << ">>////(0123456789)\\ \\ \\ +(0123456789) ////hh(0123456789)ddd\\ \\ \\ ////(0123456789)"
+            << ">>(0123456)p+(0123456)-(01234)(234567)(56789)"
+            << ">>////(0123456789)\\ \\ \\ +(0123456789) ////hh(0123456789)ddd\\ \\ \\ ////(0123456789)-\\(0123456789)\\ \\ \\ (0123456789) ////hh+(0123456789)dd\\ \\ \\ ////-(0123456789)"
             << "d(012)>h(123)>d(012)<d(234)>hh(23)(42)(12)(43)>d012342";
 
         writeRcFile();
@@ -1331,7 +1342,7 @@ void MainWindow::recentFileActivated(QAction *action)
 {
     if (!action->text().isEmpty()) {
         if (isSave())
-            openFile(action->text());
+            openFile(action->text().remove('&'));
     }
 }
 
@@ -1346,17 +1357,6 @@ void MainWindow::addRecentlyOpenedFile(const QString &fn, QStringList &lst)
     lst.prepend(fi.absoluteFilePath());
 }
 
-void MainWindow::appendRecentlyOpenedFile(const QString &fn, QStringList &lst)
-{
-    QFileInfo fi(fn);
-    if (lst.contains(fi.absoluteFilePath()))
-        return;
-    if (lst.count() >= 6 )
-        lst.removeFirst();
-
-    lst.append(fi.absoluteFilePath());
-}
-
 void MainWindow::updatePatternPresets(const QString& n, const QString& p,
         int index)
 {
@@ -1417,6 +1417,7 @@ void MainWindow::handleSignal(int sig)
 
 bool MainWindow::installSignalHandlers()
 {
+#ifdef SIGUSR1
     /*install pipe to forward received system signals*/
     if (pipe(sigpipe) < 0) {
         qWarning("pipe() failed: %s", std::strerror(errno));
@@ -1452,11 +1453,15 @@ bool MainWindow::installSignalHandlers()
     }
 #endif
 
+#endif
     return true;
 }
 
 void MainWindow::signalAction(int fd)
 {
+#ifndef SIGUSR1
+	(void)fd;
+#else
     int message;
 
     if (read(fd, &message, sizeof(message)) == -1) {
@@ -1480,6 +1485,7 @@ void MainWindow::signalAction(int fd)
             qWarning("Unexpected signal received: %d", message);
             break;
     }
+#endif
 }
 
 void MainWindow::jsAction(int evtype)
