@@ -3,7 +3,7 @@
  * @brief Member definitions for the MainWindow top-level UI class.
  *
  *
- *      Copyright 2009 - 2016 <qmidiarp-devel@lists.sourceforge.net>
+ *      Copyright 2009 - 2017 <qmidiarp-devel@lists.sourceforge.net>
  *
  *      This program is free software; you can redistribute it and/or modify
  *      it under the terms of the GNU General Public License as published by
@@ -25,37 +25,25 @@
 #ifndef MAINWINDOW_H
 #define MAINWINDOW_H
 
-#include <QAction>
 #include <QApplication>
-#include <QBoxLayout>
 #include <QCloseEvent>
-#include <QComboBox>
-#include <QDockWidget>
 #include <QMessageBox>
 #include <QMainWindow>
-#include <QString>
 #include <QToolBar>
 
 #include "logwidget.h"
-#include "engine.h"
 #include "midicctable.h"
 #include "passwidget.h"
 #include "globstore.h"
-#include "groovewidget.h"
-#include "config.h"
 
 #ifdef NSM
 #include "nsm.h"
 #endif
 
-#ifdef JACK_SESSION
-#include <jack/session.h>
-#endif
-
 
 static const char ABOUTMSG[] =
             "<html> <p><b><big>" APP_NAME " " PACKAGE_VERSION "</big></b></p>"
-            "<p>(C) 2009 - 2016 Frank Kober<br/>"
+            "<p>(C) 2009 - 2017 Frank Kober<br/>"
             "(C) 2011 Nedko Arnaudov<br/>"
             "(C) 2009 Guido Scholz<br/>"
             "(C) 2002-2003 Matthias Nagorni (SuSE AG Nuremberg)<br/></p>"
@@ -235,20 +223,10 @@ class MainWindow : public QMainWindow
 * It is called by openFile if the opening was successful.
 * @param fn Filename with full path to be prepended
 * @param lst The list of recently opened files
-* @see appendRecentlyOpenedFile, setupRecentFilesMenu
+* @see setupRecentFilesMenu
 */
     void addRecentlyOpenedFile(const QString &fn, QStringList &lst);
 /*!
-* @brief  appends a filename at the end of the recently
-* opened files list.
-*
-* It is called by openFile if the opening was successful.
-* @param fn Filename with full path to be appended
-* @param lst The list of recently opened files
-* @see addRecentlyOpenedFile, setupRecentFilesMenu
-*/
-    void appendRecentlyOpenedFile(const QString &fn, QStringList &lst);
-/*!
 * @brief  checks whether a .qmidiarprc file is present
 * and creates it with default settings, if not.
 * @return True if the file existed, False if it was created now.
@@ -314,12 +292,6 @@ class MainWindow : public QMainWindow
 * @see midiClockToggle, jackSyncToggle
 */
     void setGUIforExtSync(bool on);
-/*!
-* @brief  restarts the transport position if rolling and does
-* nothing if it is stopped
-*
-*/
-    void resetTransport();
 
 /*! @brief Handler for system signals (SIGUSR1, SIGINT...).
  * This function writes a message to the pipe and leaves as soon as possible
@@ -331,6 +303,16 @@ class MainWindow : public QMainWindow
  * @return True if installation succeeded.
 */
     bool installSignalHandlers();
+/*!
+* @brief allows ignoring one XML element in the XML stream
+* passed by the caller.
+*
+* It also advances the stream read-in. It is used to
+* ignore unknown elements for both-ways-compatibility
+*
+* @param xml reference to QXmlStreamReader containing the open XML stream
+*/
+    void skipXmlElement(QXmlStreamReader& xml);
 
   protected:
 /*!
