@@ -3,7 +3,7 @@
  * @brief Implements the MidiArp MIDI worker class for the Arpeggiator Module.
  *
  *
- *      Copyright 2009 - 2016 <qmidiarp-devel@lists.sourceforge.net>
+ *      Copyright 2009 - 2017 <qmidiarp-devel@lists.sourceforge.net>
  *
  *      This program is free software; you can redistribute it and/or modify
  *      it under the terms of the GNU General Public License as published by
@@ -23,7 +23,8 @@
  */
 #include <cstdlib>
 #include <cstdio>
-#include <QString>
+#include <iostream>
+
 #include "midiarp.h"
 
 /*
@@ -84,6 +85,7 @@ MidiArp::MidiArp()
 */
     noteBufPtr = 0;
     releaseNoteCount = 0;
+    purgeReleaseFlag = false;
     stepWidth = 1.0;     // stepWidth relative to global queue stepWidth
     minStepWidth = 1.0;
     maxOctave = 0;
@@ -96,18 +98,16 @@ MidiArp::MidiArp()
     octIncr = 0;
 
     nSteps = 1.0;
-    nPoints = 1;
     len = 0.5;       // note length
     vel = 0.8;  // velocity relative to global velocity
     noteIndex[0] = 0;
     patternIndex = 0;
-    grooveIndex = 0;
     patternLen = 0;
     semitone = 0;
-    currentNoteTick = 0;
     patternMaxIndex = 0;
     noteOfs = 0;
     arpTick = 0;
+    returnTick = 0;
     chordMode = false;
     randomTick = 0;
     randomVelocity = 0;
@@ -120,24 +120,21 @@ MidiArp::MidiArp()
     attack_time = 0.0;
     release_time = 0.0;
     sustain = false;
-    sustainBuffer.resize(64);
     sustainBufferCount = 0;
     latch_mode = false;
-    latchBuffer.resize(64);
     latchBufferCount = 0;
     lastLatchTick = 0;
     trigDelayTicks = 4;
-
-    returnNote.resize(128);
-    returnVelocity.resize(128);
 }
 
 bool MidiArp::handleEvent(MidiEvent inEv, int tick, int keep_rel)
 {
-    int bufPtr = 0;
-    int index = 0;
-
-    if (inEv.channel != chIn) return(true);
+    if (inEv.channel != chIn && chIn != OMNI) return(true);
+    if ((inEv.type == EV_CONTROLLER) && 
+        ((inEv.data == CT_ALLNOTESOFF) || (inEv.data == CT_ALLSOUNDOFF))) {
+        clearNoteBuffer();
+        return(true); // In case we receive all notes off we still forward
+    }
     if ((inEv.type == EV_CONTROLLER) && (inEv.data == CT_FOOTSW)) {
         setSustain((inEv.value == 127), tick);
         return(false);
@@ -151,43 +148,18 @@ bool MidiArp::handleEvent(MidiEvent inEv, int tick, int keep_rel)
 
     if (inEv.value) {
         // This is a NOTE ON event
-        
         if (!getPressedNoteCount() || trigLegato) {
-            purgeLatchBuffer();
+            purgeLatchBuffer(tick);
             if (restartByKbd) restartFlag = true;
             // if we have been triggered, remove pending release notes
-            if (trigByKbd && release_time > 0) {
-                for (int l1 = 0; l1 < noteCount; l1++) {
-                    if (notes[bufPtr][3][l1])
-                        removeNote(&notes[noteBufPtr][0][l1], -1, 0);
-                }
-            }
+            if (trigByKbd && release_time > 0) purgeReleaseNotes(noteBufPtr);
         }
-        // modify buffer that is not accessed by arpeggio output
-        bufPtr = (noteBufPtr) ? 0 : 1;
-
-        if (!noteCount || (inEv.data > notes[bufPtr][0][noteCount - 1]))
-            index = noteCount;
-        else {
-            index = 0;
-            while (inEv.data > notes[bufPtr][0][index]) index++;
-
-            for (int l3 = 0; l3 < 4; l3++) {
-                for (int l2 = noteCount; l2 > index; l2--) {
-                    notes[bufPtr][l3][l2] = notes[bufPtr][l3][l2 - 1];
-                }
-            }
-        }
-        notes[bufPtr][0][index] = inEv.data;
-        notes[bufPtr][1][index] = inEv.value;
-        notes[bufPtr][2][index] = tick;
-        notes[bufPtr][3][index] = 0;
-        noteCount++;
-
+        
+        addNote(inEv.data, inEv.value, tick);
+        
         if (repeatPatternThroughChord == 2) noteOfs = noteCount - 1;
 
-        if ((trigByKbd
-                && (getPressedNoteCount() == 1))
+        if ((trigByKbd && (getPressedNoteCount() == 1))
                     || trigLegato) {
             initArpTick(tick + trigDelayTicks);
             gotKbdTrig = true;
@@ -195,52 +167,90 @@ bool MidiArp::handleEvent(MidiEvent inEv, int tick, int keep_rel)
     }
     else {
         // This is a NOTE OFF event
-        // modify buffer that is not accessed by arpeggio output
-        bufPtr = (noteBufPtr) ? 0 : 1;
 
         if (!noteCount) {
             return(false);
         }
         if (sustain) {
-            sustainBuffer.replace(sustainBufferCount, inEv.data);
+            if (sustainBufferCount == MAXNOTES - 1) purgeSustainBuffer(tick);
+            sustainBuffer[sustainBufferCount] = inEv.data;
             sustainBufferCount++;
             return(false);
         }
 
-        if (latch_mode) {
-            latchBuffer.replace(latchBufferCount, inEv.data);
+        if (latch_mode && keep_rel) {
+            if (latchBufferCount == MAXNOTES - 1) purgeLatchBuffer(tick);
+            latchBuffer[latchBufferCount] = inEv.data;
             latchBufferCount++;
             if (latchBufferCount != noteCount) {
-                if ((uint)tick > (uint)(lastLatchTick + 30) && (latchBufferCount > 1)) purgeLatchBuffer();
+                if ((uint)tick > (uint)(lastLatchTick + 30) 
+                    && (latchBufferCount > 1)) purgeLatchBuffer(tick);
                 lastLatchTick = tick;
             }
             return(false);
         }
-
-        if ((!keep_rel) || (!release_time)) {
-            //definitely remove from buffer
-            if (inEv.data == notes[bufPtr][0][noteCount - 1]) {
-                //note is on top of buffer: only decrement noteCount
-                noteCount--;
-                if (repeatPatternThroughChord == 2) noteOfs = noteCount - 1;
-            }
-            else {
-                //note is not on top: take out the note and pull down all above
-                index = 0;
-                while ((index < noteCount) && (inEv.data > notes[bufPtr][0][index])) index++;
-                deleteNoteAt(index, bufPtr);
-            }
-        }
-        else tagAsReleased(inEv.data, tick, bufPtr);
+        
+        releaseNote(inEv.data, tick, keep_rel);
     }
     
-    copyNoteBuffer();
     return(false);
 }
 
+void MidiArp::addNote(int note, int vel, int tick)
+{
+        // modify buffer that is not accessed by arpeggio output
+    int bufPtr = (noteBufPtr) ? 0 : 1;
+    int index = 0;
+
+    if (!noteCount || (note > notes[bufPtr][0][noteCount - 1])
+            || (repeatPatternThroughChord == 4) )
+        index = noteCount;
+    else {
+        while (index < MAXNOTES && note > notes[bufPtr][0][index]) index++;
+
+        for (int l3 = 0; l3 < 4; l3++) {
+            for (int l2 = noteCount; l2 > index; l2--) {
+                notes[bufPtr][l3][l2] = notes[bufPtr][l3][l2 - 1];
+            }
+        }
+    }
+    notes[bufPtr][0][index] = note;
+    notes[bufPtr][1][index] = vel;
+    notes[bufPtr][2][index] = tick;
+    notes[bufPtr][3][index] = 0;
+    noteCount++;
+
+    copyNoteBuffer();
+}
+
+void MidiArp::releaseNote(int note, int tick, bool keep_rel)
+{
+    // modify buffer that is not accessed by arpeggio output
+    int bufPtr = (noteBufPtr) ? 0 : 1;
+    if ((!keep_rel) || (!release_time)) {
+        //definitely remove from buffer
+        if (note == notes[bufPtr][0][noteCount - 1]
+                && (repeatPatternThroughChord != 4)) {
+            //note is on top of buffer: only decrement noteCount
+            noteCount--;
+            if (repeatPatternThroughChord == 2) noteOfs = noteCount - 1;
+        }
+        else {
+            //note is not on top: take out the note and pull down all above
+            int index = 0;
+            while ((index < MAXNOTES) && (index < noteCount) 
+                && (note != notes[bufPtr][0][index])) index++;
+            deleteNoteAt(index, bufPtr);
+        }
+    }
+    else tagAsReleased(note, tick, bufPtr);
+    
+    copyNoteBuffer();
+}
+
 void MidiArp::removeNote(int *noteptr, int tick, int keep_rel)
 {
-    int bufPtr, index, note ;
+    int bufPtr, note ;
     note = *noteptr;
 
     // modify buffer that is not accessed by arpeggio output
@@ -250,7 +260,8 @@ void MidiArp::removeNote(int *noteptr, int tick, int keep_rel)
     }
     if (!keep_rel || (!release_time)) {
         // definitely remove from buffer, do NOT check for doubles
-        if (note == notes[bufPtr][0][noteCount - 1]) {
+        if (note == notes[bufPtr][0][noteCount - 1]
+                && (repeatPatternThroughChord != 4)) {
             // note is on top of buffer: only decrement noteCount
             noteCount--;
             if (tick == -1) releaseNoteCount--;
@@ -258,16 +269,18 @@ void MidiArp::removeNote(int *noteptr, int tick, int keep_rel)
         }
         else {
             // note is not on top: take out the note and pull down all above
-            index = 0;
-            while ((index < noteCount) && (note > notes[bufPtr][0][index])) index++;
-
-            // additional forward in buffer to look for release marked note
-            // tick is -1 only if removeNote called after release
-            while ((index < noteCount) && (!notes[bufPtr][3][index])
-                    && (tick == -1)) {
-                index++;
+            int index = 0;
+            if (tick != -1) {
+                while ((index < noteCount) 
+                        && (note != notes[bufPtr][0][index])) index++;
+            }
+            else {
+                while ((index < noteCount) 
+                        && ((note != notes[bufPtr][0][index])
+                        || (!notes[bufPtr][3][index]))) index++;
             }
 
+            
             if (note == notes[bufPtr][0][index]) {
                 deleteNoteAt(index, bufPtr);
                 if (tick == -1) releaseNoteCount--;
@@ -296,13 +309,15 @@ void MidiArp::tagAsReleased(int note, int tick, int bufPtr)
 {
     //mark as released but keep with note off time tick
     int l1 = 0;
-    while ((l1 < noteCount) && (note > notes[bufPtr][0][l1])) l1++;
-    while ((l1 < noteCount) && (notes[bufPtr][3][l1])) l1++;
+    while ((l1 < noteCount) 
+        && ((note != notes[bufPtr][0][l1]) || (notes[bufPtr][3][l1]))) {
+        l1++;
+    }
     if (note == notes[bufPtr][0][l1]) {
         notes[bufPtr][3][l1] = 1;
         notes[bufPtr][2][l1] = tick;
+        releaseNoteCount++;
     }
-    releaseNoteCount++;
 }
 
 void MidiArp::copyNoteBuffer()
@@ -320,12 +335,11 @@ void MidiArp::copyNoteBuffer()
 
 void MidiArp::getNote(int *tick, int note[], int velocity[], int *length)
 {
-    QChar c;
+    char c;
     int l1, tmpIndex[MAXCHORD], chordIndex, grooveTmp;
     int current_octave = 0;
     bool outOfRange = false;
     bool gotCC, pause;
-    double attackfn, releasefn;
 
 
     chordIndex = 0;
@@ -333,9 +347,19 @@ void MidiArp::getNote(int *tick, int note[], int velocity[], int *length)
     tmpIndex[1] = -1;
     gotCC = false;
     pause = false;
+    
+    if (purgeReleaseFlag) {
+        purgeLatchBuffer(arpTick);
+        purgeReleaseNotes(noteBufPtr);
+        purgeReleaseFlag = false;
+    }
     if (restartFlag) advancePatternIndex(true);
 
     if (!patternIndex) initLoop();
+
+    framePtr++;
+    if (framePtr >= nPoints) framePtr = 0;
+
     chordSemitone[0] = semitone;
     do {
         if (patternLen)
@@ -344,9 +368,9 @@ void MidiArp::getNote(int *tick, int note[], int velocity[], int *length)
             c = ' ';
 
         if (c != ' ') {
-            if (c.isDigit() || (c == 'p')) {
-                tmpIndex[chordIndex] = c.digitValue() + noteOfs;
-                if (chordMode) {
+            if (isdigit(c) || (c == 'p')) {
+                tmpIndex[chordIndex] = c - '0' + noteOfs;
+                if ((chordIndex < MAXNOTES - 1) && chordMode) {
                     chordIndex++;
                     chordSemitone[chordIndex] = semitone;
                 }
@@ -356,7 +380,7 @@ void MidiArp::getNote(int *tick, int note[], int velocity[], int *length)
             else {
                 gotCC = true;
 
-                switch(c.toLatin1()) {
+                switch(c) {
                     case '(':
                         chordMode = true;
                         break;
@@ -407,7 +431,7 @@ void MidiArp::getNote(int *tick, int note[], int velocity[], int *length)
             }
         }
         current_octave = octOfs;
-    } while (advancePatternIndex(false) && (gotCC || chordMode));
+    } while (advancePatternIndex(false) && (gotCC || chordMode || c == ' '));
 
     l1 = 0;
     if (noteCount) do {
@@ -416,8 +440,9 @@ void MidiArp::getNote(int *tick, int note[], int velocity[], int *length)
                 + chordSemitone[l1], 0, 127, &outOfRange);
         if (outOfRange) checkOctaveAtEdge(false);
 
-        grooveTmp = (grooveIndex % 2) ? -grooveVelocity : grooveVelocity;
-
+        grooveTmp = (framePtr % 2) ? grooveVelocity : -grooveVelocity;
+        
+        double releasefn = 0;
         if ((release_time > 0) && (notes[noteBufPtr][3][noteIndex[l1]])) {
             releasefn = 1.0 - (double)(arpTick
                     - notes[noteBufPtr][2][noteIndex[l1]])
@@ -426,7 +451,8 @@ void MidiArp::getNote(int *tick, int note[], int velocity[], int *length)
             if (releasefn < 0.0) releasefn = 0.0;
         }
         else releasefn = 1.0;
-
+        
+        double attackfn = 0;
         if (attack_time > 0) {
             if (!notes[noteBufPtr][3][noteIndex[l1]]) {
                 attackfn = (double)(arpTick
@@ -456,21 +482,21 @@ void MidiArp::getNote(int *tick, int note[], int velocity[], int *length)
             && (noteCount));
 
     note[l1] = -1; // mark end of array
-    grooveTmp = (grooveIndex % 2) ? -grooveLength : grooveLength;
+    grooveTmp = (framePtr % 2) ? grooveLength : -grooveLength;
     *length = clip(len * stepWidth * (double)TPQN
             * (1.0 + 0.005 * (double)(randomLength + grooveTmp)), 2,
             1000000,  &outOfRange);
 
-    if (!grooveIndex) grooveTick = newGrooveTick;
+    if (!framePtr) grooveTick = newGrooveTick;
     grooveTmp = TPQN * stepWidth * grooveTick * 0.01;
     /* pairwise application of new groove shift */
-    if (grooveIndex % 2) {
+    if (!(framePtr % 2)) {
         grooveTmp = -grooveTmp;
         grooveTick = newGrooveTick;
     }
     arpTick += stepWidth * TPQN + grooveTmp;
 
-    if (!trigByKbd && !grooveIndex && !grooveTick) {
+    if (!trigByKbd && !framePtr && !grooveTick) {
         /* round-up to current resolution (quantize) */
         arpTick/= (TPQN * minStepWidth);
         arpTick*= (TPQN * minStepWidth);
@@ -482,7 +508,6 @@ void MidiArp::getNote(int *tick, int note[], int velocity[], int *length)
     if (!(patternLen && noteCount) || pause || isMuted) {
         velocity[0] = 0;
     }
-    grooveIndex++;
 }
 
 void MidiArp::checkOctaveAtEdge(bool reset)
@@ -540,6 +565,7 @@ bool MidiArp::advancePatternIndex(bool reset)
 
         switch (repeatPatternThroughChord) {
             case 1:
+            case 4:
                 noteOfs++;
                 if ((noteCount - 1 < patternMaxIndex + noteOfs) || reset) {
                     noteOfs = 0;
@@ -573,21 +599,23 @@ void MidiArp::initLoop()
     len = 0.5;
     vel = 0.8;
     semitone = 0;
-    grooveIndex = 0;
+    framePtr = 0;
 }
 
-void MidiArp::prepareCurrentNote(int askedTick)
+void MidiArp::getNextFrame(int askedTick)
 {
     gotKbdTrig = false;
+    
+    newRandomValues();
 
     int l1 = 0;
     //allow 8 ticks of tolerance for echo tick for external sync
-    if ((askedTick + 8) >= currentNoteTick) {
-        currentNoteTick = nextTick;
+    if ((askedTick + 8) >= nextTick) {
+        returnTick = nextTick;
         getNote(&nextTick, nextNote, nextVelocity, &nextLength);
         while ((l1 < MAXCHORD - 1) && (nextNote[l1] >= 0)) {
-            returnNote.replace(l1, nextNote[l1]);
-            returnVelocity.replace(l1, nextVelocity[l1]);
+            returnNote[l1] = nextNote[l1];
+            returnVelocity[l1] = nextVelocity[l1];
             l1++;
         }
         returnLength = nextLength;
@@ -595,9 +623,7 @@ void MidiArp::prepareCurrentNote(int askedTick)
     }
     else hasNewNotes = false;
     
-    returnNote.replace(l1, -1); // mark end of chord
-
-    returnTick = currentNoteTick;
+    returnNote[l1] = -1; // mark end of chord
 }
 
 void MidiArp::foldReleaseTicks(int tick)
@@ -606,48 +632,53 @@ void MidiArp::foldReleaseTicks(int tick)
 
     bufPtr = (noteBufPtr) ? 0 : 1;
 
+    if (tick <= 0) {
+        purgeReleaseNotes(bufPtr);
+        return;
+    }
+
     for (l2 = 0; l2 < noteCount; l2++) {
             notes[bufPtr][2][l2] -= tick;
     }
 
     copyNoteBuffer();
+    lastLatchTick -= tick;    
 }
 
 void MidiArp::initArpTick(int tick)
 {
     arpTick = tick;
-    returnVelocity.first() = 0;
-    currentNoteTick = tick;
+    returnVelocity[0] = 0;
     nextTick  = tick;
     nextVelocity[0] = 0;
     noteIndex[0] = -1;
     patternIndex = 0;
-    grooveIndex = 0;
+    framePtr = 0;
 }
 
-QString MidiArp::stripPattern(const QString& p_pattern)
+std::string MidiArp::stripPattern(const std::string& p_pattern)
 {
-    QString p = p_pattern;
+    std::string p = p_pattern;
     patternLen = 0;
-    if (!p.count()) return (p);
+    if (!p.length()) return (p);
 
-    QChar c = (p.at(p.count() - 1));
-    while (!c.isDigit() && (c != 'p') && (c != ')')) {
-        p = p.left(p.count() - 1);
-        if (p.count() < 1) break;
-        c = (p.at(p.count() - 1));
+    char c = p[p.length() - 1];
+    while (!isdigit(c) && (c != 'p') && (c != ')')) {
+        p = p.substr(0, p.length() - 1);
+        if (p.length() < 1) break;
+        c = p[p.length() - 1];
     }
 
-    patternLen = p.count();
+    patternLen = p.length();
 
     return (p);
 }
 
 
-void MidiArp::updatePattern(const QString& p_pattern)
+void MidiArp::updatePattern(const std::string& p_pattern)
 {
     int l1;
-    QChar c;
+    char c;
 
     pattern = p_pattern;
     patternMaxIndex = 0;
@@ -663,24 +694,23 @@ void MidiArp::updatePattern(const QString& p_pattern)
     int npoints = 0;
 
     pattern = stripPattern(pattern);
-
     // determine some useful properties of the arp pattern,
     // number of octaves, step width and number of steps in beats and
     // number of points
 
     for (l1 = 0; l1 < patternLen; l1++) {
-        c = pattern.at(l1);
+        c = pattern[l1];
 
-        if (c.isDigit()) {
+        if (isdigit(c)) {
             if (!chordindex) {
                 nsteps += stepwd;
                 npoints++;
                 if (chordmd) chordindex++;
             }
-            if (c.digitValue() > patternMaxIndex)
-                patternMaxIndex = c.digitValue();
+            if (isdigit(c) && (c  - '0' > patternMaxIndex))
+                patternMaxIndex = c - '0';
         }
-        switch(c.toLatin1()) {
+        switch(c) {
             case '(':
                 chordmd = true;
                 chordindex = 0;
@@ -706,9 +736,10 @@ void MidiArp::updatePattern(const QString& p_pattern)
                 break;
 
             case 'p':
-                if (!chordmd)
+                if (!chordmd) {
                     nsteps += stepwd;
-                    npoints++;
+               	    npoints++;
+                }
                 break;
 
             case '+':
@@ -734,7 +765,7 @@ void MidiArp::updatePattern(const QString& p_pattern)
     }
 
     patternIndex = 0;
-    grooveIndex = 0;
+    framePtr = 0;
     noteOfs = 0;
     nSteps = nsteps;
     nPoints = npoints;
@@ -742,11 +773,11 @@ void MidiArp::updatePattern(const QString& p_pattern)
 
 void MidiArp::newRandomValues()
 {
-    randomTick = (double)randomTickAmp * (0.5 - (double)random()
+    randomTick = (double)randomTickAmp * (0.5 - (double)rand()
             / (double)RAND_MAX);
-    randomVelocity = (double)randomVelocityAmp * (0.5 - (double)random()
+    randomVelocity = (double)randomVelocityAmp * (0.5 - (double)rand()
             / (double)RAND_MAX);
-    randomLength = (double)randomLengthAmp * (0.5 - (double)random()
+    randomLength = (double)randomLengthAmp * (0.5 - (double)rand()
             / (double)RAND_MAX);
 }
 
@@ -796,6 +827,8 @@ void MidiArp::updateAttackTime(int val)
 
 void MidiArp::updateReleaseTime(int val)
 {
+    if (release_time > 0 && val == 0) purgeReleaseFlag = true;
+
     release_time = (double)val;
 }
 
@@ -817,14 +850,14 @@ void MidiArp::setSustain(bool on, int sustick)
     sustain = on;
     if (!sustain) {
         purgeSustainBuffer(sustick);
-        if (latch_mode) purgeLatchBuffer();
+        if (latch_mode) purgeLatchBuffer(sustick);
     }
 }
 
 void MidiArp::purgeSustainBuffer(int sustick)
 {
     for (int l1 = 0; l1 < sustainBufferCount; l1++) {
-        int buf = sustainBuffer.at(l1);
+        int buf = sustainBuffer[l1];
         removeNote(&buf, sustick, 1);
     }
     sustainBufferCount = 0;
@@ -833,18 +866,27 @@ void MidiArp::purgeSustainBuffer(int sustick)
 void MidiArp::setLatchMode(bool on)
 {
     latch_mode = on;
-    if (!latch_mode) purgeLatchBuffer();
+    if (!latch_mode) purgeLatchBuffer(arpTick);
 }
 
-void MidiArp::purgeLatchBuffer()
+void MidiArp::purgeLatchBuffer(int latchtick)
 {
     for (int l1 = 0; l1 < latchBufferCount; l1++) {
-        int buf = latchBuffer.at(l1);
-        removeNote(&buf, arpTick, 1);
+        int buf = latchBuffer[l1];
+        removeNote(&buf, latchtick, 1);
     }
     latchBufferCount = 0;
 }
 
+void MidiArp::purgeReleaseNotes(int bufptr)
+{
+    for (int l1 = noteCount - 1; l1 >= 0; l1--) {
+        if (notes[bufptr][3][l1])
+            deleteNoteAt(l1, bufptr);
+            releaseNoteCount--;
+    }
+}
+
 void MidiArp::applyPendingParChanges()
 {
     if (!parChangesPending) return;
@@ -863,7 +905,7 @@ void MidiArp::setNextTick(int tick)
 
     returnTick = tick / (int)(nSteps*TPQN) * (int)(nSteps*TPQN);
     patternIndex = 0;
-    currentNoteTick = returnTick;
+    framePtr = 0;
     arpTick = returnTick;
     nextTick = returnTick;
 }
