@@ -3,7 +3,7 @@
  * @brief Implementation of the MidiCCTable QDialog class
  *
  *
- *      Copyright 2009 - 2016 <qmidiarp-devel@lists.sourceforge.net>
+ *      Copyright 2009 - 2017 <qmidiarp-devel@lists.sourceforge.net>
  *
  *      This program is free software; you can redistribute it and/or modify
  *      it under the terms of the GNU General Public License as published by
@@ -23,10 +23,8 @@
  */
 
 
-#include <QVector>
 #include <QDialogButtonBox>
 #include "midicctable.h"
-#include "mainwindow.h"
 
 MidiCCTable::MidiCCTable(Engine *p_engine, QWidget *parent) : QDialog(parent)
 {
@@ -75,7 +73,7 @@ void MidiCCTable::getCurrentControls()
 
     ccList = engine->midiControl->ccList;
 
-    for (l2 = 0; l2 < engine->midiControl->ccList.count(); l2++) {
+    for (l2 = 0; l2 < ccList.count(); l2++) {
 
         midiCCTable->setVerticalHeaderItem(nrows,
                 new QTableWidgetItem("Engine"));
@@ -86,7 +84,7 @@ void MidiCCTable::getCurrentControls()
 
     ccList = engine->globStoreWidget->midiControl->ccList;
 
-    for (l2 = 0; l2 < engine->globStoreWidget->midiControl->ccList.count(); l2++) {
+    for (l2 = 0; l2 < ccList.count(); l2++) {
 
         midiCCTable->setVerticalHeaderItem(nrows,
                 new QTableWidgetItem("Param Store"));
@@ -97,7 +95,7 @@ void MidiCCTable::getCurrentControls()
 
     ccList = engine->grooveWidget->midiControl->ccList;
 
-    for (l2 = 0; l2 < engine->grooveWidget->midiControl->ccList.count(); l2++) {
+    for (l2 = 0; l2 < ccList.count(); l2++) {
 
         midiCCTable->setVerticalHeaderItem(nrows,
                 new QTableWidgetItem("Groove"));
@@ -106,41 +104,18 @@ void MidiCCTable::getCurrentControls()
         nrows++;
     }
 
-    for (l1 = 0; l1 < engine->arpWidgetCount(); l1++) {
-        ccList = engine->arpWidget(l1)->midiControl->ccList;
+    for (l1 = 0; l1 < engine->moduleWindowCount(); l1++) {
+        
+        InOutBox *moduleWidget = (InOutBox *)engine->moduleWindow(l1)->widget();
+        
+        ccList = moduleWidget->midiControl->ccList;
 
-        for (l2 = 0; l2 < engine->arpWidget(l1)->midiControl->ccList.count(); l2++) {
+        for (l2 = 0; l2 < ccList.count(); l2++) {
 
             midiCCTable->setVerticalHeaderItem(nrows,
-                    new QTableWidgetItem(engine->arpWidget(l1)->name));
+                    new QTableWidgetItem(moduleWidget->name));
 
-            fillControlRow(nrows, ccList.at(l2), engine->arpWidget(l1)->ID);
-            nrows++;
-        }
-    }
-
-    for (l1 = 0; l1 < engine->lfoWidgetCount(); l1++) {
-        ccList = engine->lfoWidget(l1)->midiControl->ccList;
-
-        for (l2 = 0; l2 < engine->lfoWidget(l1)->midiControl->ccList.count(); l2++) {
-
-            midiCCTable->setVerticalHeaderItem(nrows,
-                    new QTableWidgetItem(engine->lfoWidget(l1)->name));
-
-            fillControlRow(nrows, ccList.at(l2), engine->lfoWidget(l1)->ID);
-            nrows++;
-        }
-    }
-
-    for (l1 = 0; l1 < engine->seqWidgetCount(); l1++) {
-        ccList = engine->seqWidget(l1)->midiControl->ccList;
-
-        for (l2 = 0; l2 < engine->seqWidget(l1)->midiControl->ccList.count(); l2++) {
-
-            midiCCTable->setVerticalHeaderItem(nrows,
-                    new QTableWidgetItem(engine->seqWidget(l1)->name));
-
-            fillControlRow(nrows, ccList.at(l2), engine->seqWidget(l1)->ID);
+            fillControlRow(nrows, ccList.at(l2), moduleWidget->ID);
             nrows++;
         }
     }
@@ -176,29 +151,21 @@ void MidiCCTable::accept()
 
 void MidiCCTable::apply()
 {
-    int ccnumber, channel, min, max, ctrlID, moduleID;
-    int l1;
-    QChar moduleType;
-
     engine->midiControl->ccList.clear();
     engine->globStoreWidget->midiControl->ccList.clear();
     engine->grooveWidget->midiControl->ccList.clear();
 
-    for (l1 = 0; l1 < engine->arpWidgetCount(); l1++)
-            engine->arpWidget(l1)->midiControl->ccList.clear();
-    for (l1 = 0; l1 < engine->lfoWidgetCount(); l1++)
-            engine->lfoWidget(l1)->midiControl->ccList.clear();
-    for (l1 = 0; l1 < engine->seqWidgetCount(); l1++)
-            engine->seqWidget(l1)->midiControl->ccList.clear();
+    for (int l1 = 0; l1 < engine->moduleWindowCount(); l1++)
+        ((InOutBox *)engine->moduleWindow(l1)->widget())->midiControl->ccList.clear();
 
-    for (l1 = 0; l1 < midiCCTable->rowCount(); l1++) {
-        ccnumber = midiCCTable->item(l1, 1)->text().toInt();
-        channel = midiCCTable->item(l1, 2)->text().toInt() - 1;
-        min = midiCCTable->item(l1, 3)->text().toInt();
-        max = midiCCTable->item(l1, 4)->text().toInt();
-        ctrlID = midiCCTable->item(l1, 5)->text().toInt();
-        moduleID = midiCCTable->item(l1, 6)->text().toInt();
-        moduleType = midiCCTable->verticalHeaderItem(l1)->text().at(0);
+    for (int l1 = 0; l1 < midiCCTable->rowCount(); l1++) {
+        int ccnumber = midiCCTable->item(l1, 1)->text().toInt();
+        int channel = midiCCTable->item(l1, 2)->text().toInt() - 1;
+        int min = midiCCTable->item(l1, 3)->text().toInt();
+        int max = midiCCTable->item(l1, 4)->text().toInt();
+        int ctrlID = midiCCTable->item(l1, 5)->text().toInt();
+        int moduleID = midiCCTable->item(l1, 6)->text().toInt();
+        QChar  moduleType = midiCCTable->verticalHeaderItem(l1)->text().at(0);
 
         switch (moduleType.toLatin1()) {
             case 'E':
