@@ -3,7 +3,7 @@
  * @brief Member definitions for the MidiControl QWidget class.
  *
  *
- *      Copyright 2009 - 2016 <qmidiarp-devel@lists.sourceforge.net>
+ *      Copyright 2009 - 2017 <qmidiarp-devel@lists.sourceforge.net>
  *
  *      This program is free software; you can redistribute it and/or modify
  *      it under the terms of the GNU General Public License as published by
@@ -28,10 +28,10 @@
 #include <QSignalMapper>
 #include <QStringList>
 #include <QVector>
-#include <QXmlStreamReader>
 #include <QXmlStreamWriter>
 
 #include <cstdio>
+#include "main.h"
 
 #ifndef MIDICC_H
 
@@ -54,7 +54,7 @@ struct MidiCC {
  *
  * MidiControl is instantiated by each of QMidiArp's module widgets.
  */
-class MidiControl : public QWidget
+class MidiControl : public QObject
 
 {
   Q_OBJECT
@@ -109,6 +109,19 @@ class MidiControl : public QWidget
 */
     void addMidiLearnMenu(const QString &name, QWidget *widget, int count = 0);
 
+#ifdef APPBUILD
+/*!
+* @brief allows ignoring one XML element in the XML stream
+* passed by the caller.
+*
+* It also advances the stream read-in. It is used to
+* ignore unknown elements for both-ways-compatibility
+*
+* @param xml reference to QXmlStreamReader containing the open XML stream
+*/
+void skipXmlElement(QXmlStreamReader& xml);
+#endif
+
   signals:
 /*! @brief Connected to Engine::setMidiLearn() to listen for incoming events.
 *  @param parentdockid parentDockID of the module requesting MIDI learn
