@@ -3,7 +3,7 @@
  * @brief Implements the MidiLfo MIDI worker class for the LFO Module.
  *
  *
- *      Copyright 2009 - 2016 <qmidiarp-devel@lists.sourceforge.net>
+ *      Copyright 2009 - 2017 <qmidiarp-devel@lists.sourceforge.net>
  *
  *      This program is free software; you can redistribute it and/or modify
  *      it under the terms of the GNU General Public License as published by
@@ -32,7 +32,6 @@ MidiLfo::MidiLfo()
     freq = 8;
     size = 4;
     res = 4;
-    nPoints = 16;
     maxNPoints = 16;
     old_res = 0;
     waveFormIndex = 0;
@@ -45,24 +44,26 @@ MidiLfo::MidiLfo()
     cwmin = 0;
 
     customWave.resize(8192);
+    muteMask.resize(8192);
+    data.reserve(8192);
+    frame.resize(32);
+    
     Sample sample;
     sample.value = 63;
     sample.tick = 0;
     for (l1 = 0; l1 < size * res; l1++) {
         sample.tick = lt;
         sample.muted = false;
-        customWave.replace(l1, sample);
+        customWave[l1] = sample;
+        data[l1] = sample;
+        if (l1 < 32) frame[l1] = sample;
+        muteMask[l1] = false;
         lt+=step;
     }
-    muteMask.fill(false, 8192);
-    data.clear();
-    frame.resize(32);
-    frame.fill(sample);
     updateWaveForm(waveFormIndex);
     getData(&data);
     lastMouseLoc = 0;
     lastMouseY = 0;
-    frameptr = 0;
     frameSize = 1;
 
     lastMute = false;
@@ -74,7 +75,7 @@ void MidiLfo::getNextFrame(int tick)
     //if res <= LFO_FRAMELIMIT. If res > LFO_FRAMELIMIT, a frame is output
     //The FRAMELIMIT avoids excessive cursor updating
 
-    if (frameptr >= data.size()) return;
+    if ((uint)framePtr >= data.size()) return;
     
     Sample sample;
     const int step = TPQN / res;
@@ -90,16 +91,16 @@ void MidiLfo::getNextFrame(int tick)
     if (!frameSize) frameSize = 1;
 
     if (restartFlag) setFramePtr(0);
-    if (!frameptr) grooveTick = newGrooveTick;
+    if (!framePtr) grooveTick = newGrooveTick;
 
     l1 = 0;
     lt = nextTick;
     do {
         if (reverse) {
-            index = (frameSize - 1 - l1 + frameptr) % npoints;
+            index = (frameSize - 1 - l1 + framePtr) % npoints;
         }
         else {
-            index = (l1 + frameptr) % npoints;
+            index = (l1 + framePtr) % npoints;
         }
         sample = data.at(index);
 
@@ -116,12 +117,12 @@ void MidiLfo::getNextFrame(int tick)
                             + (double)(recValue - lastSampleValue) / res * framelimit
                             * ((double)l1 + .5);
             }
-            customWave.replace(index, sample);
+            customWave[index] = sample;
             dataChanged = true;
         }
         sample.tick = lt;
         if (seqFinished) sample.muted = true;
-        frame.replace(l1, sample);
+        frame[l1] = sample;
         lt+=step;
         l1++;
     } while ((l1 < frameSize) && (l1 < npoints));
@@ -129,40 +130,40 @@ void MidiLfo::getNextFrame(int tick)
 
     reflect = pingpong;
 
-    if ((!frameptr && !reverse)
-        || (frameptr == npoints - l1 && reverse)) applyPendingParChanges();
+    if ((!framePtr && !reverse)
+        || (framePtr == npoints - l1 && reverse)) applyPendingParChanges();
 
     if (curLoopMode == 6) {
-        frameptr = (rand() % npoints) / l1;
-        frameptr *= l1;
+        framePtr = (rand() % npoints) / l1;
+        framePtr *= l1;
     }
     else {
         if (reverse) {
-            frameptr-=l1;
-            if (frameptr < 0) {
+            framePtr-=l1;
+            if (framePtr < 0) {
                 if (!enableLoop) seqFinished = true;
-                frameptr = npoints - l1;
+                framePtr = npoints - l1;
                 if (reflect  || !backward) {
                     reverse = false;
-                    frameptr = 0;
+                    framePtr = 0;
                 }
             }
         }
         else {
-            frameptr+=l1;
-            if (frameptr >= npoints) {
+            framePtr+=l1;
+            if (framePtr >= npoints) {
                 if (!enableLoop) seqFinished = true;
-                frameptr = 0;
+                framePtr = 0;
                 if (reflect || backward) {
                     reverse = true;
-                    frameptr = npoints - l1;
+                    framePtr = npoints - l1;
                 }
             }
         }
     }
     int cur_grv_sft = 0.01 * (grooveTick * (step - 1));
     /* pairwise application of new groove shift */
-    if (!(frameptr % 2)) {
+    if (!(framePtr % 2)) {
         cur_grv_sft = -cur_grv_sft;
         grooveTick = newGrooveTick;
     }
@@ -174,53 +175,51 @@ void MidiLfo::getNextFrame(int tick)
     if (nextTick < (tick - lt)) nextTick = tick;
     sample.value = -1;
     sample.tick = nextTick;
-    frame.replace(l1, sample);
+    frame[l1] = sample;
 
-    if (!trigByKbd && !(frameptr % 2) && !grooveTick) {
+    if (!trigByKbd && !(framePtr % 2) && !grooveTick) {
         /* round-up to current resolution (quantize) */
         nextTick/= (step * frameSize);
         nextTick*= (step * frameSize);
     }
 
-    if (seqFinished) frameptr = 0;
+    if (seqFinished) framePtr = 0;
 
 }
 
-void MidiLfo::getData(QVector<Sample> *p_data)
+void MidiLfo::getData(std::vector<Sample> *p_data)
 {
     //this function returns the full LFO wave
 
     Sample sample;
     const int step = TPQN / res;
     const int npoints = size * res;
-    int l1 = 0;
-    int lt = 0;
     int val = 0;
-    int tempval;
+    int lt = 0;
     bool cl = false;
-    QVector<Sample> tmpdata;
+    std::vector<Sample> tmpdata;
 
     tmpdata.clear();
 
     switch(waveFormIndex) {
         case 0: //sine
-            for (l1 = 0; l1 < npoints; l1++) {
+            for (int l1 = 0; l1 < npoints; l1++) {
                 sample.value = clip((-cos((double)(l1 * 6.28 /
                 res * freq / 32)) + 1) * amp / 2 + offs, 0, 127, &cl);
                 sample.tick = lt;
                 sample.muted = muteMask.at(l1);
-                tmpdata.append(sample);
+                tmpdata.push_back(sample);
                 lt += step;
             }
         break;
         case 1: //sawtooth up
             val = 0;
-            for (l1 = 0; l1 < npoints; l1++) {
+            for (int l1 = 0; l1 < npoints; l1++) {
                 sample.value = clip(val * amp / res / 32
                 + offs, 0, 127, &cl);
                 sample.tick = lt;
                 sample.muted = muteMask.at(l1);
-                tmpdata.append(sample);
+                tmpdata.push_back(sample);
                 lt += step;
                 val += freq;
                 val %= res * 32;
@@ -228,14 +227,14 @@ void MidiLfo::getData(QVector<Sample> *p_data)
         break;
         case 2: //triangle
             val = 0;
-            for (l1 = 0; l1 < npoints; l1++) {
-                tempval = val - res * 16;
+            for (int l1 = 0; l1 < npoints; l1++) {
+                int tempval = val - res * 16;
                 if (tempval < 0 ) tempval = -tempval;
                 sample.value = clip((res * 16 - tempval) * amp
                         / res / 16 + offs, 0, 127, &cl);
                 sample.tick = lt;
                 sample.muted = muteMask.at(l1);
-                tmpdata.append(sample);
+                tmpdata.push_back(sample);
                 lt += step;
                 val += freq;
                 val %= res * 32;
@@ -243,37 +242,39 @@ void MidiLfo::getData(QVector<Sample> *p_data)
         break;
         case 3: //sawtooth down
             val = 0;
-            for (l1 = 0; l1 < npoints; l1++) {
+            for (int l1 = 0; l1 < npoints; l1++) {
                 sample.value = clip((res * 32 - val)
                         * amp / res / 32 + offs, 0, 127, &cl);
                 sample.tick = lt;
                 sample.muted = muteMask.at(l1);
-                tmpdata.append(sample);
+                tmpdata.push_back(sample);
                 lt+=step;
                 val += freq;
                 val %= res * 32;
             }
         break;
         case 4: //square
-            for (l1 = 0; l1 < npoints; l1++) {
+            for (int l1 = 0; l1 < npoints; l1++) {
                 sample.value = clip(amp * ((l1 * freq / 16
                         / res) % 2 == 0) + offs, 0, 127, &cl);
                 sample.tick = lt;
                 sample.muted = muteMask.at(l1);
-                tmpdata.append(sample);
+                tmpdata.push_back(sample);
                 lt+=step;
             }
         break;
         case 5: //custom
+            for (int l1 = 0; l1 < npoints; l1++) {
+                tmpdata.push_back(customWave[l1]);
+            }
             lt = step * npoints;
-            tmpdata = customWave.mid(0, npoints);
         break;
         default:
         break;
     }
     sample.value = -1;
     sample.tick = lt;
-    tmpdata.append(sample);
+    tmpdata.push_back(sample);
     data = tmpdata;
     *p_data = data;
 }
@@ -349,9 +350,9 @@ int MidiLfo::setCustomWavePoint(double mouseX, double mouseY, bool newpt)
             lastMouseY -= (double)(lastMouseY - Y) / (lastMouseLoc - loc) - .5;
             lastMouseLoc--;
         }
-        sample = customWave.at(lastMouseLoc);
+        sample = customWave[lastMouseLoc];
         sample.value = lastMouseY;
-        customWave.replace(lastMouseLoc, sample);
+        customWave[lastMouseLoc] = sample;
     } while (lastMouseLoc != loc);
 
     newCustomOffset();
@@ -379,22 +380,21 @@ int MidiLfo::mouseEvent(double mouseX, double mouseY, int buttons, int pressed)
 
 void MidiLfo::resizeAll()
 {
-    int lt = 0;
-    int l1 = 0;
     const int step = TPQN / res;
     const int npoints = res * size;
     Sample sample;
 
-    frameptr%=npoints;
+    framePtr%=npoints;
 
     if (maxNPoints < npoints) {
-        for (l1 = 0; l1 < npoints; l1++) {
+        int lt = 0;
+        for (int l1 = 0; l1 < npoints; l1++) {
             if (l1 >= maxNPoints)
-                muteMask.replace(l1, muteMask.at(l1 % maxNPoints));
-            sample = customWave.at(l1 % maxNPoints);
+                muteMask[l1] = muteMask[l1 % maxNPoints];
+            sample = customWave[l1 % maxNPoints];
             sample.tick = lt;
-            sample.muted = muteMask.at(l1);
-            customWave.replace(l1, sample);
+            sample.muted = muteMask[l1];
+            customWave[l1] = sample;
             lt+=step;
         }
         maxNPoints = npoints;
@@ -407,17 +407,16 @@ void MidiLfo::copyToCustom()
 {
     updateWaveForm(5);
     for (int l1 = 0; l1 < nPoints; l1++)
-        customWave.replace(l1, data.at(l1));
+        customWave[l1] = data[l1];
 
 }
 
 void MidiLfo::newCustomOffset()
 {
     int min = 127;
-    int value;
     const int npoints = res * size;
     for (int l1 = 0; l1 < npoints; l1++) {
-        value = customWave.at(l1).value;
+        int value = customWave[l1].value;
         if (value < min) min = value;
     }
     cwmin = min;
@@ -431,23 +430,22 @@ void MidiLfo::flipWaveVertical()
     Sample sample;
     int min = 127;
     int max = 0;
-    int value, l1;
     const int npoints = res * size;
     
     if (waveFormIndex < 5) {
         copyToCustom();
     }
     
-    for (l1 = 0; l1 < npoints; l1++) {
-        value = customWave.at(l1).value;
+    for (int l1 = 0; l1 < npoints; l1++) {
+        int value = customWave[l1].value;
         if (value < min) min = value;
         if (value > max) max = value;
     }
 
-    for (l1 = 0; l1 < npoints; l1++) {
-        sample = customWave.at(l1);
+    for (int l1 = 0; l1 < npoints; l1++) {
+        sample = customWave[l1];
         sample.value = min + max - sample.value;
-        customWave.replace(l1, sample);
+        customWave[l1] = sample;
     }
     cwmin = min;
 #ifdef APPBUILD
@@ -463,7 +461,7 @@ void MidiLfo::updateCustomWaveOffset(int o)
     bool cl = false;
 
     while ((!cl) && (l1 < count)) {
-        sample.value = clip(customWave.at(l1).value + o - cwmin,
+        sample.value = clip(customWave[l1].value + o - cwmin,
                             0, 127, &cl);
         l1++;
         }
@@ -471,9 +469,9 @@ void MidiLfo::updateCustomWaveOffset(int o)
     if (cl) return;
 
     for (l1 = 0; l1 < count; l1++) {
-        sample = customWave.at(l1);
+        sample = customWave[l1];
         sample.value += o - cwmin;
-        customWave.replace(l1, sample);
+        customWave[l1] = sample;
     }
     cwmin = o;
 }
@@ -485,11 +483,11 @@ bool MidiLfo::toggleMutePoint(double mouseX)
     int loc = mouseX * (res * size);
 
     m = muteMask.at(loc);
-    muteMask.replace(loc, !m);
+    muteMask[loc] = !m;
     if (waveFormIndex == 5) {
-        sample = customWave.at(loc);
+        sample = customWave[loc];
         sample.muted = !m;
-        customWave.replace(loc, sample);
+        customWave[loc] = sample;
     }
     lastMouseLoc = loc;
     return(!m);
@@ -504,11 +502,11 @@ int MidiLfo::setMutePoint(double mouseX, bool on)
 
     do {
         if (waveFormIndex == 5) {
-            sample = customWave.at(lastMouseLoc);
+            sample = customWave[lastMouseLoc];
             sample.muted = on;
-            customWave.replace(lastMouseLoc, sample);
+            customWave[lastMouseLoc] = sample;
         }
-        muteMask.replace(lastMouseLoc, on);
+        muteMask[lastMouseLoc] = on;
         if (loc > lastMouseLoc) lastMouseLoc++;
         if (loc < lastMouseLoc) lastMouseLoc--;
     } while (lastMouseLoc != loc);
@@ -518,12 +516,12 @@ int MidiLfo::setMutePoint(double mouseX, bool on)
 
 void MidiLfo::setFramePtr(int idx)
 {
-    frameptr = idx;
+    framePtr = idx;
     if (!idx) {
         reverse = curLoopMode&1;
         seqFinished = (enableNoteOff && !noteCount);
         restartFlag = false;
-        if (reverse) frameptr = res * size - 1;
+        if (reverse) framePtr = res * size - 1;
     }
 }
 
@@ -547,7 +545,7 @@ bool MidiLfo::handleEvent(MidiEvent inEv, int tick)
 {
 
     if (!recordMode && (inEv.type == EV_CONTROLLER)) return(true);
-    if (inEv.channel != chIn) return(true);
+    if (inEv.channel != chIn && chIn != OMNI) return(true);
     if ((inEv.type == EV_CONTROLLER) && (inEv.data != ccnumberIn)) return(true);
 
     if ((inEv.type == EV_CONTROLLER) && recordMode) {
