@@ -3,7 +3,7 @@
  * @brief Member definitions for the MidiLfo MIDI worker class.
  *
  *
- *      Copyright 2009 - 2016 <qmidiarp-devel@lists.sourceforge.net>
+ *      Copyright 2009 - 2017 <qmidiarp-devel@lists.sourceforge.net>
  *
  *      This program is free software; you can redistribute it and/or modify
  *      it under the terms of the GNU General Public License as published by
@@ -25,11 +25,7 @@
 #ifndef MIDILFO_H
 #define MIDILFO_H
 
-#include <QObject>
-#include <QString>
-#include <QVector>
-#include "main.h"
-
+#include <vector>
 #include "midiworker.h"
 
 
@@ -52,8 +48,6 @@
  */
 class MidiLfo : public MidiWorker  {
 
-  Q_OBJECT
-
   private:
     int lastMouseLoc;   /*!< The X location of the last modification of the wave, used for interpolation*/
     int lastMouseY;     /*!< The Y location at the last modification of the wave, used for interpolation*/
@@ -75,9 +69,7 @@ class MidiLfo : public MidiWorker  {
     int size;       /*!< Size of the waveform in quarter notes */
     int res;        /*!< Resolution of the waveform in ticks per quarter note */
     int frameSize;  /*!< Current size of a vector returned by MidiLfo::getNextFrame() */
-    int nPoints;        /*!< Number of steps to be played out */
     int maxNPoints;        /*!< Maximum number of steps that have been used in the session */
-    int frameptr;       /*!< position of the currently output frame in the MidiArp::data waveform */
     int waveFormIndex;          /*!< Index of the waveform to produce
                                     @par 0: Sine
                                     @par 1: Sawtooth Up
@@ -86,13 +78,14 @@ class MidiLfo : public MidiWorker  {
                                     @par 4: Square
                                     @par 5: Use Custom Wave */
     int cwmin;                  /*!< The minimum of MidiLfo::customWave */
-    QVector<Sample> customWave; /*!< Vector of Sample points holding the custom drawn wave */
-    QVector<bool> muteMask;     /*!< Vector of booleans with mute state information for each wave point */
-    QVector<Sample> frame; /*!< Vector of Sample points holding the current frame for transfer */
-    QVector<Sample> data;
+    std::vector<Sample> customWave; /*!< Vector of Sample points holding the custom drawn wave */
+    std::vector<bool> muteMask;     /*!< Vector of booleans with mute state information for each wave point */
+    std::vector<Sample> frame; /*!< Vector of Sample points holding the current frame for transfer */
+    std::vector<Sample> data;
 
   public:
     MidiLfo();
+    virtual ~MidiLfo() {}
     void updateWaveForm(int val);
     void updateFrequency(int);
     void updateAmplitude(int);
@@ -115,12 +108,6 @@ class MidiLfo : public MidiWorker  {
 */
     void newCustomOffset();
 
-/*! @brief  sets MidiLfo::deferChanges, which will cause a
- * parameter changes only at pattern end.
- *
- * @param on Set to True to defer changes to pattern end
- */
-    void updateDeferChanges(bool on) { deferChanges = on; }
 /*! @brief  sets the (controller) value of one point of the
  * MidiLfo::customWave array. It is used for handling drawing functionality.
  *
@@ -178,10 +165,10 @@ class MidiLfo : public MidiWorker  {
  * It is called by LfoWidget when the vertical flip button is pressed.
  */
     void flipWaveVertical();
-/*! @brief  sets the MidiLfo::frameptr to the given value.
+/*! @brief  sets the MidiLfo::framePtr to the given value.
  *
  * It is called when the Transport starts.
- * @param idx Index to which the frameptr is set
+ * @param idx Index to which the framePtr is set
  */
     void setFramePtr(int idx);
 /**
@@ -204,7 +191,7 @@ class MidiLfo : public MidiWorker  {
  *
  * @param *data reference to an array the waveform is copied to
  */
-    void getData(QVector<Sample> *data);
+    void getData(std::vector<Sample> *data);
 /*! @brief fills the MidiLfo::frame with Sample data points taken from
  * the currently active waveform MidiLfo::data.
  *
@@ -229,7 +216,6 @@ class MidiLfo : public MidiWorker  {
  */
     bool toggleMutePoint(double mouseX);
 
-    int getFramePtr() { return frameptr;}
 /*! @brief Checks if deferred parameter changes are pending and applies
  * them if so
  */
