@@ -3,7 +3,7 @@
  * @brief Implements the MidiSeq MIDI worker class for the Seq Module.
  *
  *
- *      Copyright 2009 - 2016 <qmidiarp-devel@lists.sourceforge.net>
+ *      Copyright 2009 - 2017 <qmidiarp-devel@lists.sourceforge.net>
  *
  *      This program is free software; you can redistribute it and/or modify
  *      it under the terms of the GNU General Public License as published by
@@ -28,7 +28,6 @@
 MidiSeq::MidiSeq()
 {
     recordMode = false;
-    enableLoop = true;
     currentRecStep = 0;
     loopMarker = 0;
 
@@ -41,33 +40,36 @@ MidiSeq::MidiSeq()
     transpDefer = 0;
     size = 4;
     res = 4;
-    nPoints = 16;
     maxNPoints = 16;
     notelength = 180;
     notelengthDefer = 180;
-    currentIndex = 0;
     lastMute = false;
+    lastMouseLoc = 0;
 
+    customWave.resize(2048);
+    muteMask.resize(2048);
+    data.reserve(2048);
+    
     int lt = 0;
     int l1 = 0;
     int step = TPQN / res;
     Sample sample;
     sample.value = 60;
-    customWave.resize(2048);
-    muteMask.resize(2048);
     for (l1 = 0; l1 < 2048; l1++) {
-            sample.tick = lt;
-            sample.muted = false;
-            customWave.replace(l1, sample);
-            lt+=step;
+        sample.tick = lt;
+        sample.muted = false;
+        customWave[l1] = sample;
+        data[l1] = sample;
+        muteMask[l1] = false;
+        lt+=step;
     }
-    muteMask.fill(false, 2048);
+    returnNote = sample;
 }
 
 bool MidiSeq::handleEvent(MidiEvent inEv, int tick)
 {
     if (inEv.type != EV_NOTEON) return(true);
-    if (inEv.channel != chIn) return(true);
+    if (inEv.channel != chIn && chIn != OMNI) return(true);
     if ((inEv.data < 36) || (inEv.data >= 84)) return(true);
 
     if (inEv.value) {
@@ -105,17 +107,17 @@ bool MidiSeq::handleEvent(MidiEvent inEv, int tick)
     return(false);
 }
 
-void MidiSeq::getNextNote(Sample *p_sample, int tick)
+void MidiSeq::getNextFrame(int tick)
 {
     const int frame_nticks = TPQN / res;
     Sample sample;
     int cur_grv_sft;
 
     gotKbdTrig = false;
-    if (restartFlag) setCurrentIndex(0);
-    if (!currentIndex) grooveTick = newGrooveTick;
+    if (restartFlag) setFramePtr(0);
+    if (!framePtr) grooveTick = newGrooveTick;
 
-    sample = customWave.at(currentIndex);
+    sample = customWave[framePtr];
     advancePatternIndex();
 
     if (nextTick < (tick - frame_nticks)) nextTick = tick;
@@ -127,13 +129,13 @@ void MidiSeq::getNextNote(Sample *p_sample, int tick)
     cur_grv_sft = 0.01 * (grooveTick * (frame_nticks - 1));
 
     /* pairwise application of new groove shift */
-    if (!(currentIndex % 2)) {
+    if (!(framePtr % 2)) {
         cur_grv_sft = -cur_grv_sft;
         grooveTick = newGrooveTick;
     }
     nextTick += frame_nticks + cur_grv_sft;
 
-    if (!trigByKbd && !(currentIndex % 2)) {
+    if (!trigByKbd && !(framePtr % 2)) {
         /* round-up to current resolution (quantize) */
         nextTick/=frame_nticks;
         nextTick*=frame_nticks;
@@ -141,9 +143,9 @@ void MidiSeq::getNextNote(Sample *p_sample, int tick)
 
     if (seqFinished) {
         sample.muted = true;
-        currentIndex = 0;
+        framePtr = 0;
     }
-    *p_sample = sample;
+    returnNote = sample;
 }
 
 void MidiSeq::advancePatternIndex()
@@ -154,75 +156,77 @@ void MidiSeq::advancePatternIndex()
 
     if (curLoopMode == 6) {
         if (pivot)
-            currentIndex = rand() % pivot;
+            framePtr = rand() % pivot;
         else
-            currentIndex = rand() % npoints;
+            framePtr = rand() % npoints;
         return;
     }
 
     if (reverse) {
         if (!pivot) pivot = npoints;
-        if (currentIndex == pivot - 1) applyPendingParChanges();
-        currentIndex--;
-        if (currentIndex == -1) {
+        if (framePtr == pivot - 1) applyPendingParChanges();
+        framePtr--;
+        if (framePtr == -1) {
             if (!enableLoop) seqFinished = true;
             if (reflect  || !backward) {
                 reverse = false;
-                currentIndex = 0;
+                framePtr = 0;
             }
-            else currentIndex = pivot - 1;
+            else framePtr = pivot - 1;
         }
-        else if (currentIndex == pivot - 1) {
+        else if (framePtr == pivot - 1) {
             if (!enableLoop) seqFinished = true;
             if (loopMarker < 0) reflect = true;
             if (loopMarker > 0) reflect = false;
             if (reflect) {
                 reverse = false;
-                currentIndex = pivot;
+                framePtr = pivot;
             }
-            else currentIndex = npoints - 1;
+            else framePtr = npoints - 1;
         }
     }
     else {
-        if (!currentIndex) applyPendingParChanges();
-        currentIndex++;
-        if (currentIndex == npoints) {
+        if (!framePtr) applyPendingParChanges();
+        framePtr++;
+        if (framePtr == npoints) {
             if (!enableLoop) seqFinished = true;
 
             if (reflect || backward) {
                 reverse = true;
-                currentIndex = npoints - 1;
+                framePtr = npoints - 1;
             }
-            else currentIndex = pivot;
+            else framePtr = pivot;
         }
-        else if ((currentIndex == pivot)) {
+        else if ((framePtr == pivot)) {
             if (!pivot) pivot = npoints;
             if (!enableLoop) seqFinished = true;
             if (loopMarker > 0) reflect = true;
             if (loopMarker < 0) reflect = false;
             if (reflect) {
                 reverse = true;
-                currentIndex = pivot - 1;
+                framePtr = pivot - 1;
             }
-            else currentIndex = 0;
+            else framePtr = 0;
         }
     }
 }
 
-void MidiSeq::getData(QVector<Sample> *p_data)
+void MidiSeq::getData(std::vector<Sample> * p_data)
 {
     Sample sample;
     int lt = 0;
+    int l1 = 0;
     const int step = TPQN / res;
     const int npoints = res * size;
 
-    QVector<Sample> data;
+    data.resize(npoints);
 
     lt = step * npoints;
-    data = customWave.mid(0, npoints);
+    for (l1 = 0; l1 < npoints; l1++) data[l1] = customWave[l1];
     sample.value = -1;
     sample.tick = lt;
-    data.append(sample);
+    data.push_back(sample);
+    
     *p_data = data;
 }
 
@@ -246,7 +250,7 @@ void MidiSeq::updateLoop(int val)
     curLoopMode = val;
     if (seqFinished) {
         seqFinished = false;
-        setCurrentIndex(0);
+        setFramePtr(0);
     }
 }
 
@@ -371,31 +375,30 @@ void MidiSeq::setRecordedNote(int note)
 {
     Sample sample;
 
-    sample = customWave.at(currentRecStep);
+    sample = customWave[currentRecStep];
     sample.value = note;
     sample.tick = currentRecStep * TPQN / res;
-    customWave.replace(currentRecStep, sample);
+    customWave[currentRecStep] = sample;
 }
 
 void MidiSeq::resizeAll()
 {
-    int lt = 0;
-    int l1 = 0;
     const int step = TPQN / res;
     const int npoints = res * size;
     Sample sample;
 
-    currentIndex%=npoints;
+    framePtr%=npoints;
     currentRecStep%=npoints;
 
     if (maxNPoints < npoints) {
-        for (l1 = 0; l1 < npoints; l1++) {
+        int lt = 0;
+        for (int l1 = 0; l1 < npoints; l1++) {
             if (l1 >= maxNPoints)
-                muteMask.replace(l1, muteMask.at(l1 % maxNPoints));
-            sample = customWave.at(l1 % maxNPoints);
+                muteMask[l1] = muteMask[l1 % maxNPoints];
+            sample = customWave[l1 % maxNPoints];
             sample.tick = lt;
-            sample.muted = muteMask.at(l1);
-            customWave.replace(l1, sample);
+            sample.muted = muteMask[l1];
+            customWave[l1] = sample;
             lt+=step;
         }
         maxNPoints = npoints;
@@ -412,11 +415,11 @@ bool MidiSeq::toggleMutePoint(double mouseX)
     bool m;
     int loc = mouseX * (res * size);
 
-    m = muteMask.at(loc);
-    muteMask.replace(loc, !m);
-    sample = customWave.at(loc);
+    m = muteMask[loc];
+    muteMask[loc] = !m;
+    sample = customWave[loc];
     sample.muted = !m;
-    customWave.replace(loc, sample);
+    customWave[loc] = sample;
     return(!m);
 }
 
@@ -425,24 +428,24 @@ int MidiSeq::setMutePoint(double mouseX, bool on)
     Sample sample;
     int loc = mouseX * (res * size);
 
-    sample = customWave.at(loc);
+    sample = customWave[loc];
     sample.muted = on;
-    customWave.replace(loc, sample);
-    muteMask.replace(loc, on);
+    customWave[loc] = sample;
+    muteMask[loc] = on;
     return (loc);
 }
 
-void MidiSeq::setCurrentIndex(int ix)
+void MidiSeq::setFramePtr(int ix)
 {
-    currentIndex=ix;
+    framePtr=ix;
 
     if (!ix) {
         seqFinished = (enableNoteOff && !noteCount);
         restartFlag = false;
         if (backward) {
             reverse = true;
-            if (loopMarker) currentIndex = abs(loopMarker) - 1;
-            else currentIndex = res * size - 1;
+            if (loopMarker) framePtr = abs(loopMarker) - 1;
+            else framePtr = res * size - 1;
         }
         else reverse = false;
 
@@ -479,6 +482,6 @@ void MidiSeq::setNextTick(int tick)
     if (backward) reverse = !reverse;
     if (reverse) pos = nPoints - pos;
 
-    setCurrentIndex(pos);
+    setFramePtr(pos);
     nextTick = (tick/tickres) * tickres;
 }
