@@ -3,7 +3,7 @@
  * @brief Implements an LV2 plugin inheriting from MidiSeq
  *
  *
- *      Copyright 2009 - 2016 <qmidiarp-devel@lists.sourceforge.net>
+ *      Copyright 2009 - 2017 <qmidiarp-devel@lists.sourceforge.net>
  *
  *      This program is free software; you can redistribute it and/or modify
  *      it under the terms of the GNU General Public License as published by
@@ -33,7 +33,6 @@ MidiSeqLV2::MidiSeqLV2 (
     MidiEventID = 0;
     sampleRate = sample_rate;
     curFrame = 0;
-    nCalls = 0;
     inEventBuffer = NULL;
     outEventBuffer = NULL;
     getData(&data);
@@ -57,8 +56,6 @@ MidiSeqLV2::MidiSeqLV2 (
     velFromGui = 256;
 
     bufPtr = 0;
-    evQueue.resize(JQ_BUFSZ);
-    evTickQueue.resize(JQ_BUFSZ);
     dataChanged = true;
     ui_up = false;
 
@@ -76,7 +73,7 @@ MidiSeqLV2::MidiSeqLV2 (
         }
     }
     if (!urid_map) {
-        qWarning("Host does not support urid:map.");
+        printf("Host does not support urid:map.\n");
         return;
     }
 
@@ -158,7 +155,7 @@ void MidiSeqLV2::updatePos(uint64_t pos, float bpm, int speed, bool ignore_pos)
             setNextTick(tempoChangeTick);
         }
     }
-    //qWarning("transportBpm %f, transportFramesDelta %d", transportBpm, transportFramesDelta);
+    //printf("transportBpm %f, transportFramesDelta %d\n", transportBpm, transportFramesDelta);
 }
 
 void MidiSeqLV2::run (uint32_t nframes )
@@ -195,7 +192,7 @@ void MidiSeqLV2::run (uint32_t nframes )
             // MIDI Input
             else if (event && event->body.type == MidiEventID) {
                 uint8_t *di = (uint8_t *) LV2_ATOM_BODY(&event->body);
-                MidiEvent inEv;
+                MidiEvent inEv = {0, 0, 0, 0};
                 if ( (di[0] & 0xf0) == 0x90 ) {
                     inEv.type = EV_NOTEON;
                     inEv.value = di[2];
@@ -212,8 +209,9 @@ void MidiSeqLV2::run (uint32_t nframes )
 
                 inEv.channel = di[0] & 0x0f;
                 inEv.data=di[1];
-                int tick = (uint64_t)(curFrame - transportFramesDelta)
-                            *TPQN*tempo/60/sampleRate + tempoChangeTick;
+                int tick = ((uint64_t)(curFrame - transportFramesDelta) * nframes
+                            +(uint64_t)(&event->time.frames) % nframes)
+                            *TPQN*tempo/nframes/60/sampleRate + tempoChangeTick;
                 if (handleEvent(inEv, tick - 2)) //if event is unmatched, forward it
                     forgeMidiEvent((int)((uint64_t)(&event->time.frames) % nframes), di, 3);
             }
@@ -226,27 +224,26 @@ void MidiSeqLV2::run (uint32_t nframes )
         curTick = (uint64_t)(curFrame - transportFramesDelta)
                         *TPQN*tempo/60/sampleRate + tempoChangeTick;
         if ((curTick >= nextTick) && (transportSpeed)) {
-            getNextNote(&currentSample, curTick);
-            if (!currentSample.muted && !isMuted) {
+            getNextFrame(curTick);
+            if (!returnNote.muted && !isMuted) {
                 unsigned char d[3];
                 d[0] = 0x90 + channelOut;
-                d[1] = currentSample.value;
+                d[1] = returnNote.value;
                 d[2] = vel;
                 forgeMidiEvent(f, d, 3);
-                evTickQueue.replace(bufPtr, curTick + notelength / 4);
-                evQueue.replace(bufPtr, currentSample.value);
+                evTickQueue[bufPtr] = curTick + notelength / 4;
+                evQueue[bufPtr] = returnNote.value;
                 bufPtr++;
             }
-            float pos = (float)getCurrentIndex();
+            float pos = (float)getFramePtr();
             *val[CURSOR_POS] = pos;
         }
 
         // Note Off Queue handling
-        int noteofftick = evTickQueue.first();
-        int tmptick = 0;
+        int noteofftick = evTickQueue[0];
         int idx = 0;
         for (int l1 = 0; l1 < bufPtr; l1++) {
-            tmptick = evTickQueue.at(l1);
+            int tmptick = evTickQueue[l1];
             if (noteofftick > tmptick) {
                 idx = l1;
                 noteofftick = tmptick;
@@ -254,10 +251,10 @@ void MidiSeqLV2::run (uint32_t nframes )
         }
         if ( (bufPtr) && ((curTick >= noteofftick)
                 || (hostTransport && !transportSpeed)) ) {
-            int outval = evQueue.at(idx);
+            int outval = evQueue[idx];
             for (int l4 = idx ; l4 < (bufPtr - 1);l4++) {
-                evQueue.replace(l4, evQueue.at(l4 + 1));
-                evTickQueue.replace(l4, evTickQueue.at(l4 + 1));
+                evQueue[l4] = evQueue[l4 + 1];
+                evTickQueue[l4] = evTickQueue[l4 + 1];
             }
             bufPtr--;
 
@@ -269,8 +266,6 @@ void MidiSeqLV2::run (uint32_t nframes )
         }
         curFrame++;
     }
-
-    nCalls++;
 }
 
 void MidiSeqLV2::forgeMidiEvent(uint32_t f, const uint8_t* const buffer, uint32_t size)
@@ -418,7 +413,7 @@ void MidiSeqLV2::sendWave()
     int tempArray[ct];
 
     for (int l1 = 0; l1 < ct; l1++) {
-        tempArray[l1]=data.at(l1).value*((data.at(l1).muted) ? -1 : 1);
+        tempArray[l1]=data[l1].value*((data[l1].muted) ? -1 : 1);
     }
 
     /* forge container object of type 'hex_customwave' */
@@ -457,18 +452,15 @@ static LV2_State_Status MidiSeqLV2_state_restore ( LV2_Handle instance,
     const char *value1
         = (const char *) (*retrieve)(handle, key, &size, &type, &flags);
 
-    QByteArray tmpArray1 = QByteArray::fromHex(value1);
+    if (size < 2) return LV2_STATE_ERR_UNKNOWN;
 
-    if (size < 2 || !tmpArray1.count()) return LV2_STATE_ERR_UNKNOWN;
+    pPlugin->setFramePtr(0);
+    pPlugin->maxNPoints = (size - 1 ) / 2;
 
-    pPlugin->setCurrentIndex(0);
-    pPlugin->maxNPoints = tmpArray1.count();
-
-    for (l1 = 0; l1 < tmpArray1.count(); l1++) {
-        pPlugin->muteMask.replace(l1, tmpArray1.at(l1));
+    for (l1 = 0; l1 <  pPlugin->maxNPoints; l1++) {
+        pPlugin->muteMask[l1] = (value1[2 * l1 + 1] == '1');
     }
 
-
     key = uris->hex_customwave;
     if (!key) return LV2_STATE_ERR_NO_PROPERTY;
 
@@ -477,18 +469,26 @@ static LV2_State_Status MidiSeqLV2_state_restore ( LV2_Handle instance,
 
     if (size < 2) return LV2_STATE_ERR_UNKNOWN;
 
-    QByteArray tmpArray = QByteArray::fromHex(value);
-
     Sample sample;
     int step = TPQN / pPlugin->res;
     int lt = 0;
-    for (l1 = 0; l1 < tmpArray.count(); l1++) {
-        sample.value = tmpArray.at(l1);
+
+    for (l1 = 0; l1 <  pPlugin->maxNPoints; l1++) {
+        int hi = 0;
+        int lo = 0;
+        if (value[2*l1] <= '9' && value[2*l1] >= '0') hi = value[2*l1] - '0';
+        if (value[2*l1] <= 'f' && value[2*l1] >= 'a') hi = value[2*l1] - 'a' + 10;
+
+        if (value[2*l1 + 1] <= '9' && value[2*l1 + 1] >= '0') lo = value[2*l1 + 1] - '0';
+        if (value[2*l1 + 1] <= 'f' && value[2*l1 + 1] >= 'a') lo = value[2*l1 + 1] - 'a' + 10;
+
+        sample.value = hi * 16 + lo;
         sample.tick = lt;
-        sample.muted = pPlugin->muteMask.at(l1);
-        pPlugin->customWave.replace(l1, sample);
+        sample.muted = pPlugin->muteMask[l1];
+        pPlugin->customWave[l1] = sample;
         lt+=step;
     }
+
     pPlugin->getData(&pPlugin->data);
     pPlugin->dataChanged = true;
     return LV2_STATE_SUCCESS;
@@ -499,7 +499,7 @@ static LV2_State_Status MidiSeqLV2_state_save ( LV2_Handle instance,
     uint32_t flags, const LV2_Feature* const* )
 {
     MidiSeqLV2 *pPlugin = static_cast<MidiSeqLV2 *> (instance);
-
+    
     if (pPlugin == NULL) return LV2_STATE_ERR_UNKNOWN;
 
     QMidiArpURIs* const uris = &pPlugin->m_uris;
@@ -508,33 +508,34 @@ static LV2_State_Status MidiSeqLV2_state_save ( LV2_Handle instance,
 
     if (type == 0) return LV2_STATE_ERR_BAD_TYPE;
 
-    QByteArray tempArray;
+    flags |= (LV2_STATE_IS_POD | LV2_STATE_IS_PORTABLE);
 
-    tempArray.clear();
+    const char hexmap[] = {'0', '1', '2', '3', '4', '5', '6', '7',
+                           '8', '9', 'a', 'b', 'c', 'd', 'e', 'f'};
     int l1;
+    char bt[pPlugin->maxNPoints * 2 + 1];
+    
     for (l1 = 0; l1 < pPlugin->maxNPoints; l1++) {
-        tempArray.append(pPlugin->customWave.at(l1).value);
+        bt[2*l1] = hexmap[(pPlugin->customWave[l1].value  & 0xF0) >> 4];
+        bt[2*l1 + 1] = hexmap[pPlugin->customWave[l1].value  & 0x0F];
     }
-
-    const QByteArray hexArray = tempArray.toHex();
-    const char *value = hexArray.constData();
-
+    bt[pPlugin->maxNPoints * 2] = '\0';
+    
+    const char *value = bt;
+    
     size_t size = strlen(value) + 1;
+    
     uint32_t key = uris->hex_customwave;
     if (!key) return LV2_STATE_ERR_NO_PROPERTY;
 
-    flags |= (LV2_STATE_IS_POD | LV2_STATE_IS_PORTABLE);
-
     store(handle, key, value, size, type, flags);
 
-    tempArray.clear();
-
     for (l1 = 0; l1 < pPlugin->maxNPoints; l1++) {
-        tempArray.append(pPlugin->muteMask.at(l1));
+        bt[2*l1] = '0';
+        bt[2*l1 + 1] = hexmap[pPlugin->muteMask[l1]];
     }
 
-    const QByteArray hexArray1 = tempArray.toHex();
-    const char *value1 = hexArray1.constData();
+    const char *value1 = bt;
 
     size = strlen(value1) + 1;
     key = uris->hex_mutemask;
