@@ -3,7 +3,7 @@
  * @brief Implements the ParStore class.
  *
  *
- *      Copyright 2009 - 2016 <qmidiarp-devel@lists.sourceforge.net>
+ *      Copyright 2009 - 2017 <qmidiarp-devel@lists.sourceforge.net>
  *
  *      This program is free software; you can redistribute it and/or modify
  *      it under the terms of the GNU General Public License as published by
@@ -73,20 +73,17 @@ ParStore::ParStore(GlobStore *p_globStore, const QString &name,
     ndc = new Indicator(14, name.at(0));
 
     topButton = new QToolButton;
-    topButton->setFont(QFont("Helvetica", 8));
     topButton->setText(name);
     topButton->setMinimumSize(QSize(75, 10));
 
     muteOutAction = p_muteOutAction;
     muteOut = new QToolButton;
     muteOut->setDefaultAction(muteOutAction);
-    muteOut->setFont(QFont("Helvetica", 8));
     muteOut->setMinimumSize(QSize(10, 10));
 
     deferChangesAction = p_deferChangesAction;
     deferChanges = new QToolButton;
     deferChanges->setDefaultAction(deferChangesAction);
-    deferChanges->setFont(QFont("Helvetica", 8));
     deferChanges->setMinimumSize(QSize(10, 10));
 
     QHBoxLayout *muteRowLayout = new QHBoxLayout;
@@ -117,7 +114,7 @@ ParStore::ParStore(GlobStore *p_globStore, const QString &name,
     topRowLayout->addLayout(controlLayout);
     topRowLayout->setSpacing(0);
     topRowLayout->setMargin(0);
-    topRow->setMinimumSize(QSize(48,46));;
+    topRow->setMinimumSize(QSize(104,46));;
     topRow->setFrameStyle(QFrame::StyledPanel);
     topRow->setLayout(topRowLayout);
 
@@ -170,7 +167,7 @@ ParStore::ParStore(GlobStore *p_globStore, const QString &name,
 
     globStore->indivButtonLayout->addWidget(this);
 
-
+    isRestoreMaster = false;
     restoreRequest = -1;
     oldRestoreRequest = 0;
     restoreRunOnce = false;
@@ -183,7 +180,6 @@ ParStore::ParStore(GlobStore *p_globStore, const QString &name,
 
 void ParStore::writeData(QXmlStreamWriter& xml)
 {
-    int l1;
     QByteArray tempArray;
 
     xml.writeStartElement("globalStores");
@@ -226,7 +222,7 @@ void ParStore::writeData(QXmlStreamWriter& xml)
             xml.writeTextElement("onlyPattern", QString::number((int)onlyPatternList.at(ix)));
 
             tempArray.clear();
-            l1 = 0;
+            int l1 = 0;
             while (l1 < list.at(ix).muteMask.count()) {
                 tempArray.append(list.at(ix).muteMask.at(l1));
                 l1++;
@@ -388,10 +384,28 @@ void ParStore::readData(QXmlStreamReader& xml)
     }
 }
 
+void ParStore::skipXmlElement(QXmlStreamReader& xml)
+{
+    if (xml.isStartElement()) {
+        qWarning("Unknown Element in XML File: %s",qPrintable(xml.name().toString()));
+        while (!xml.atEnd()) {
+            xml.readNext();
+
+            if (xml.isEndElement())
+                break;
+
+            if (xml.isStartElement()) {
+                skipXmlElement(xml);
+            }
+        }
+    }
+}
+
 void ParStore::addLocation()
 {
     StorageButton *toolButton = new StorageButton(this);
     toolButton->setText(QString::number(list.count()));
+    toolButton->setStyleSheet("font: 10pt");
     toolButton->setProperty("index", list.count());
     connect(toolButton, SIGNAL(pressed()), this, SLOT(mapRestoreSignal()));
 
@@ -472,7 +486,7 @@ void ParStore::setBGColorAt(int row, int color)
     if (color == 1)         //green
         styleSheet = "QToolButton { background-color: rgba(50, 255, 50, 40%); }";
     else if (color == 2)    //yellow
-        styleSheet = "QToolButton { background-color: rgba(80, 255, 80, 10%); }";
+        styleSheet = "QToolButton { background-color: rgba(150, 255, 150, 10%); }";
     else if (color == 3)    //blueish
         styleSheet = "QToolButton { }";
     else                    //no color
@@ -510,12 +524,9 @@ void ParStore::mapStoreSignal()
 
 void ParStore::setDispState(int ix, int selected)
 {
-    int l2;
-    int color;
     if (selected == 1) {
-        for (l2 = 1; l2 <= list.count(); l2++) {
-            color = 3 * (jumpToList.at(l2 - 1) > -2);
-            setBGColorAt(l2, color);
+        for (int l2 = 1; l2 <= list.count(); l2++) {
+            setBGColorAt(l2, 3 * (jumpToList.at(l2 - 1) > -2));
         }
         setBGColorAt(ix + 1, 1);
         activeStore = ix;
