@@ -3,7 +3,7 @@
  * @brief Member definitions for the ParStore class.
  *
  *
- *      Copyright 2009 - 2016 <qmidiarp-devel@lists.sourceforge.net>
+ *      Copyright 2009 - 2017 <qmidiarp-devel@lists.sourceforge.net>
  *
  *      This program is free software; you can redistribute it and/or modify
  *      it under the terms of the GNU General Public License as published by
@@ -24,19 +24,11 @@
 #ifndef PARSTORE_H
 #define PARSTORE_H
 
-#include <QObject>
-#include <QWidget>
-#include <QList>
 #include <QMenu>
-#include <QString>
 #include <QToolButton>
-#include <QVector>
-#include <QXmlStreamReader>
-#include <QXmlStreamWriter>
 
 #include "globstore.h"
-#include "indicator.h"
-#include "main.h"
+#include "midievent.h"
 
 
 /*!
@@ -79,6 +71,7 @@ class ParStore : public QWidget
 
     int activeStore; /**< Currently active location index*/
     int currentRequest; /**< Currently pending location index*/
+    bool isRestoreMaster; /**< @brief Indicates whether this module triggers global restores */
 
     struct TempStore {
         bool empty;
@@ -191,6 +184,19 @@ class ParStore : public QWidget
 * @param reverse Set to true if the parent module currently plays backward
 */
     void updateDisplay(int frame, bool reverse);
+    
+#ifdef APPBUILD
+/*!
+* @brief allows ignoring one XML element in the XML stream
+* passed by the caller.
+*
+* It also advances the stream read-in. It is used to
+* ignore unknown elements for both-ways-compatibility
+*
+* @param xml reference to QXmlStreamReader containing the open XML stream
+*/
+void skipXmlElement(QXmlStreamReader& xml);
+#endif
 
   signals:
 /*!
