@@ -3,7 +3,7 @@
  * @brief Headers for the PassWidget UI class.
  *
  *
- *      Copyright 2009 - 2016 <qmidiarp-devel@lists.sourceforge.net>
+ *      Copyright 2009 - 2017 <qmidiarp-devel@lists.sourceforge.net>
  *
  *      This program is free software; you can redistribute it and/or modify
  *      it under the terms of the GNU General Public License as published by
@@ -24,9 +24,7 @@
 #ifndef PASSWIDGET_H
 #define PASSWIDGET_H
 
-#include <QComboBox>
 #include <QDialog>
-#include <QSpinBox>
 
 #include "engine.h"
 
