@@ -3,7 +3,7 @@
  * @brief Header for the SeqDriver class
  *
  *
- *      Copyright 2009 - 2016 <qmidiarp-devel@lists.sourceforge.net>
+ *      Copyright 2009 - 2017 <qmidiarp-devel@lists.sourceforge.net>
  *
  *      This program is free software; you can redistribute it and/or modify
  *      it under the terms of the GNU General Public License as published by
@@ -21,18 +21,16 @@
  *      MA 02110-1301, USA.
  *
  */
+ 
 #ifndef SEQDRIVER_H
 #define SEQDRIVER_H
 
-#include <QWidget>
-#include <QThread>
+#include "config.h"
+
+#ifdef HAVE_ALSA
 #include <alsa/asoundlib.h>
 
 #include "jackdriver.h"
-#include "midiarp.h"
-#include "midilfo.h"
-#include "midiseq.h"
-#include "main.h"
 #include "driverbase.h"
 
 /*! @brief ALSA sequencer backend QThread class.
@@ -89,7 +87,6 @@ class SeqDriver : public DriverBase {
         int lastRatioTick;
         int midiTempoRefreshTick;
         int lastSchedTick;
-        int jackOffsetTick;
         int tempoChangeTick;
         uint64_t tempoChangeFrame;
 
@@ -123,3 +120,4 @@ class SeqDriver : public DriverBase {
 };
 
 #endif
+#endif
