@@ -3,7 +3,7 @@
  * @brief Implementation of the SeqScreen class
  *
  *
- *      Copyright 2009 - 2016 <qmidiarp-devel@lists.sourceforge.net>
+ *      Copyright 2009 - 2017 <qmidiarp-devel@lists.sourceforge.net>
  *
  *      This program is free software; you can redistribute it and/or modify
  *      it under the terms of the GNU General Public License as published by
@@ -22,44 +22,29 @@
  *
  */
 
-#include <QPainter>
-#include <QPaintDevice>
-#include <QPen>
-#include <QPixmap>
-
 #include "seqscreen.h"
-#include "engine.h"
-
 
 SeqScreen::SeqScreen()
 {
     setPalette(QPalette(QColor(0, 20, 100), QColor(0, 20, 100)));
-    mouseX = 0;
-    mouseY = 0;
     baseOctave = 3;
     nOctaves= 4;
-    recordMode = false;
     currentRecStep = 0;
     loopMarker = 0;
     currentIndex = 0;
-    grooveTick = 0;
-    grooveVelocity = 0;
-    grooveLength = 0;
-    isMuted = false;
-    needsRedraw = false;
 }
 
 // Paint event handler.
 void SeqScreen::paintEvent(QPaintEvent*)
 {
+    if (p_data.isEmpty()) return;
+
     QPainter p(this);
     QPen pen;
     pen.setWidth(1);
     p.setFont(QFont("Helvetica", 8));
     p.setPen(pen);
 
-    int l1, l2;
-    double nsteps = 0.0;
     int beat = 4;
     int tmpval = 0;
     int ypos, xpos, xscale, yscale;
@@ -70,15 +55,11 @@ void SeqScreen::paintEvent(QPaintEvent*)
     int minOctave = baseOctave;
     int maxOctave = nOctaves + minOctave;
     int notestreak_thick = 16 / nOctaves;
-    int beatRes = 1.0;
-    int beatDiv = 0;
-    l2 = 0;
 
     //Grid setup
-    if (p_data.isEmpty()) return;
-    nsteps = p_data.at(p_data.count() - 1).tick / TPQN;
-    beatRes = (p_data.count() - 1) / nsteps;
-    beatDiv = (beatRes * nsteps > 64) ? 64 / nsteps : beatRes;
+    double nsteps = p_data.at(p_data.count() - 1).tick / TPQN;
+    int beatRes = (p_data.count() - 1) / nsteps;
+    int beatDiv = (beatRes * nsteps > 64) ? 64 / nsteps : beatRes;
     int npoints = beatRes * nsteps;
     xscale = (w - 2 * SEQSCR_HMARG) / nsteps;
     yscale = h - 2 * SEQSCR_VMARG;
@@ -100,7 +81,7 @@ void SeqScreen::paintEvent(QPaintEvent*)
                 , h - 2*SEQSCR_VMARG, QColor(5, 40, 100));
 
     //Beat separators
-    for (l1 = 0; l1 < nsteps + 1; l1++) {
+    for (int l1 = 0; l1 < nsteps + 1; l1++) {
 
         if (l1 < 10) {
             ofs = w / nsteps * .5 - 4 + SEQSCR_HMARG;
@@ -117,15 +98,13 @@ void SeqScreen::paintEvent(QPaintEvent*)
                 SEQSCR_HMARG + x, h-SEQSCR_VMARG);
 
         if (l1 < nsteps) {
-            p.setPen(QColor(100, 150, 180));
-
             //Beat numbers
+            p.setPen(QColor(100, 150, 180));
             p.drawText(ofs + x, SEQSCR_VMARG, QString::number(l1+1));
 
             // Beat divisor separators
             p.setPen(QColor(20, 60, 120));
-            x1 = x;
-            for (l2 = 1; l2 < beatDiv; l2++) {
+            for (int l2 = 1; l2 < beatDiv; l2++) {
                 x1 = x + l2 * xscale / beatDiv;
                 if (x1 < xscale * nsteps)
                     p.drawLine(SEQSCR_HMARG + x1,
@@ -136,9 +115,8 @@ void SeqScreen::paintEvent(QPaintEvent*)
     }
 
     //Horizontal separators and numbers
-    int l3 = 0;
-    for (l1 = 0; l1 <= nOctaves * 12; l1++) {
-        l3 = l1%12;
+    for (int l1 = 0; l1 <= nOctaves * 12; l1++) {
+        int l3 = l1%12;
 
         ypos = yscale * l1 / nOctaves / 12 + SEQSCR_VMARG;
 
@@ -167,7 +145,7 @@ void SeqScreen::paintEvent(QPaintEvent*)
 
     pen.setWidth(notestreak_thick);
     p.setPen(pen);
-    for (l1 = 0; l1 < npoints; l1++) {
+    for (int l1 = 0; l1 < npoints; l1++) {
         x = (l1 + .01 * (double)grooveTick * (l1 % 2)) * nsteps * xscale / npoints;
         tmpval = p_data.at(l1).value;
         if ((tmpval >= 12 * baseOctave) && (tmpval < 12 * maxOctave)) {
@@ -217,26 +195,6 @@ void SeqScreen::paintEvent(QPaintEvent*)
     }
 }
 
-void SeqScreen::updateData(const QVector<Sample>& data)
-{
-    p_data = data;
-    needsRedraw = true;
-}
-
-void SeqScreen::newGrooveValues(int tick, int vel, int length)
-{
-    grooveTick = tick;
-    grooveVelocity = vel;
-    grooveLength = length;
-    needsRedraw = true;
-}
-
-void SeqScreen::setMuted(bool on)
-{
-    isMuted = on;
-    needsRedraw = true;
-}
-
 void SeqScreen::emitMouseEvent(QMouseEvent *event, int pressed)
 {
     mouseX = event->x();
@@ -248,24 +206,9 @@ void SeqScreen::emitMouseEvent(QMouseEvent *event, int pressed)
                 (h - 2 * SEQSCR_VMARG), event->buttons(), pressed);
 }
 
-void SeqScreen::mouseMoveEvent(QMouseEvent *event)
+void SeqScreen::updateData(const QVector<Sample>& data)
 {
-    emitMouseEvent(event, 0);
-}
-
-void SeqScreen::mousePressEvent(QMouseEvent *event)
-{
-    emitMouseEvent(event, 1);
-}
-
-void SeqScreen::mouseReleaseEvent(QMouseEvent *event)
-{
-    emitMouseEvent(event, 2);
-}
-
-void SeqScreen::setRecordMode(bool on)
-{
-    recordMode = on;
+    p_data = data;
     needsRedraw = true;
 }
 
@@ -281,13 +224,6 @@ void SeqScreen::setLoopMarker(int pos)
     needsRedraw = true;
 }
 
-void SeqScreen::updateDraw()
-{
-    if (!needsRedraw) return;
-    needsRedraw = false;
-    update();
-}
-
 void SeqScreen::updateDispVert(int mode)
 {
     switch (mode) {
@@ -313,14 +249,3 @@ void SeqScreen::updateDispVert(int mode)
     }
     update();
 }
-
-QSize SeqScreen::sizeHint() const
-{
-    return QSize(SEQSCR_MIN_W, SEQSCR_MIN_H);
-}
-
-QSizePolicy SeqScreen::sizePolicy() const
-{
-    return QSizePolicy(QSizePolicy::MinimumExpanding,
-            QSizePolicy::MinimumExpanding);
-}
