@@ -3,7 +3,7 @@
  * @brief Member definitions for the SeqWidget GUI class.
  *
  *
- *      Copyright 2009 - 2016 <qmidiarp-devel@lists.sourceforge.net>
+ *      Copyright 2009 - 2017 <qmidiarp-devel@lists.sourceforge.net>
  *
  *      This program is free software; you can redistribute it and/or modify
  *      it under the terms of the GNU General Public License as published by
@@ -24,18 +24,7 @@
 #ifndef SEQWIDGET_H
 #define SEQWIDGET_H
 
-#include <QString>
-#include <QComboBox>
-#include <QSpinBox>
-#include <QTextStream>
-#include <QCheckBox>
-#include <QAction>
-#include <QToolButton>
-#include <QPushButton>
 #include <QSignalMapper>
-#include <QVector>
-#include <QXmlStreamReader>
-#include <QXmlStreamWriter>
 
 #include "midiseq.h"
 #include "inoutbox.h"
@@ -58,7 +47,7 @@ class SeqWidget : public InOutBox
 {
     Q_OBJECT
 
-    MidiSeq *midiWorker;
+    MidiSeq *midiSeq;
     bool lastMute;      /**< Contains the mute state of the last waveForm point modified by mouse click*/
     bool recordMode;    /**< Is set to True if incoming notes are to be step-recorded*/
 
@@ -69,7 +58,7 @@ class SeqWidget : public InOutBox
  * @brief Constructor for SeqWidget. It creates the GUI and an SeqScreen
  * instance.
  *
- * @param p_midiWorker Associated MidiSeq Object
+ * @param p_midiSeq Associated MidiSeq Object
  * @param p_globStore The Application-wide globStore widget
  * @param portCount Number of available MIDI output ports
  * @param compactStyle If set to True, Widget will use reduced spacing and small fonts
@@ -77,7 +66,7 @@ class SeqWidget : public InOutBox
  * @param inOutVisible Add the module with visible InOutBox or not
  * @param name The name of the module preceded by its type (Arp: , etc...)
  */
-    SeqWidget(MidiSeq *p_midiWorker, GlobStore *p_globStore,
+    SeqWidget(MidiSeq *p_midiSeq, GlobStore *p_globStore,
             int portCount, bool compactStyle,
             bool mutedAdd = false, bool inOutVisible = true,
             const QString& name = "");
@@ -103,6 +92,7 @@ class SeqWidget : public InOutBox
     int sizeBoxIndex;
 
     QVector<Sample> getCustomWave();
+    QVector<bool> getMuteMask();
 
 
 #ifdef APPBUILD
@@ -139,7 +129,7 @@ class SeqWidget : public InOutBox
     void doRestoreParams(int ix);
     void updateDisplay();
     void handleController(int ccnumber, int channel, int value);
-
+    void updateCursorPos() {cursor->updatePosition(getFramePtr()); }
 #endif
 
 /* SIGNALS */
@@ -227,10 +217,8 @@ class SeqWidget : public InOutBox
 */
     void mouseEvent(double, double, int, int pressed);
 
-    int getCurrentIndex() { return midiWorker->getCurrentIndex(); }
-    int getLoopMarker() { return midiWorker->loopMarker; }
-    int getNextTick() { return midiWorker->nextTick; }
-    bool getReverse() { return midiWorker->reverse; }
+    int getLoopMarker() { return midiSeq->loopMarker; }
+    bool getReverse() { return midiSeq->reverse; }
     int sliderToTickLen(int val) { return (val * TPQN / 64); }
     int tickLenToSlider(int val) { return (val * 64 / TPQN); }
 };
