@@ -7,7 +7,7 @@
  * can be set as well as the display orientation.
  *
  *
- *      Copyright 2009 - 2016 <qmidiarp-devel@lists.sourceforge.net>
+ *      Copyright 2009 - 2017 <qmidiarp-devel@lists.sourceforge.net>
  *
  *      This program is free software; you can redistribute it and/or modify
  *      it under the terms of the GNU General Public License as published by
@@ -28,10 +28,8 @@
 #ifndef SLIDER_H
 #define SLIDER_H
 
-#include <QString>
 #include <QSlider>
 #include <QSpinBox>
-#include <QWidget>
 
 
 class Slider : public QWidget
